#include <stdint.h>
// forward declare yyscan_t to improve type safety
#define YY_TYPEDEF_YY_SCANNER_T
struct yyguts_t;
typedef yyguts_t *yyscan_t;

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define commentcnvYY_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer commentcnvYY_create_buffer
#endif

#ifdef yy_delete_buffer
#define commentcnvYY_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer commentcnvYY_delete_buffer
#endif

#ifdef yy_scan_buffer
#define commentcnvYY_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer commentcnvYY_scan_buffer
#endif

#ifdef yy_scan_string
#define commentcnvYY_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string commentcnvYY_scan_string
#endif

#ifdef yy_scan_bytes
#define commentcnvYY_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes commentcnvYY_scan_bytes
#endif

#ifdef yy_init_buffer
#define commentcnvYY_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer commentcnvYY_init_buffer
#endif

#ifdef yy_flush_buffer
#define commentcnvYY_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer commentcnvYY_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define commentcnvYY_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state commentcnvYY_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define commentcnvYY_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer commentcnvYY_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define commentcnvYYpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state commentcnvYYpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define commentcnvYYpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state commentcnvYYpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define commentcnvYYensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack commentcnvYYensure_buffer_stack
#endif

#ifdef yylex
#define commentcnvYYlex_ALREADY_DEFINED
#else
#define yylex commentcnvYYlex
#endif

#ifdef yyrestart
#define commentcnvYYrestart_ALREADY_DEFINED
#else
#define yyrestart commentcnvYYrestart
#endif

#ifdef yylex_init
#define commentcnvYYlex_init_ALREADY_DEFINED
#else
#define yylex_init commentcnvYYlex_init
#endif

#ifdef yylex_init_extra
#define commentcnvYYlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra commentcnvYYlex_init_extra
#endif

#ifdef yylex_destroy
#define commentcnvYYlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy commentcnvYYlex_destroy
#endif

#ifdef yyget_debug
#define commentcnvYYget_debug_ALREADY_DEFINED
#else
#define yyget_debug commentcnvYYget_debug
#endif

#ifdef yyset_debug
#define commentcnvYYset_debug_ALREADY_DEFINED
#else
#define yyset_debug commentcnvYYset_debug
#endif

#ifdef yyget_extra
#define commentcnvYYget_extra_ALREADY_DEFINED
#else
#define yyget_extra commentcnvYYget_extra
#endif

#ifdef yyset_extra
#define commentcnvYYset_extra_ALREADY_DEFINED
#else
#define yyset_extra commentcnvYYset_extra
#endif

#ifdef yyget_in
#define commentcnvYYget_in_ALREADY_DEFINED
#else
#define yyget_in commentcnvYYget_in
#endif

#ifdef yyset_in
#define commentcnvYYset_in_ALREADY_DEFINED
#else
#define yyset_in commentcnvYYset_in
#endif

#ifdef yyget_out
#define commentcnvYYget_out_ALREADY_DEFINED
#else
#define yyget_out commentcnvYYget_out
#endif

#ifdef yyset_out
#define commentcnvYYset_out_ALREADY_DEFINED
#else
#define yyset_out commentcnvYYset_out
#endif

#ifdef yyget_leng
#define commentcnvYYget_leng_ALREADY_DEFINED
#else
#define yyget_leng commentcnvYYget_leng
#endif

#ifdef yyget_text
#define commentcnvYYget_text_ALREADY_DEFINED
#else
#define yyget_text commentcnvYYget_text
#endif

#ifdef yyget_lineno
#define commentcnvYYget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno commentcnvYYget_lineno
#endif

#ifdef yyset_lineno
#define commentcnvYYset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno commentcnvYYset_lineno
#endif

#ifdef yyget_column
#define commentcnvYYget_column_ALREADY_DEFINED
#else
#define yyget_column commentcnvYYget_column
#endif

#ifdef yyset_column
#define commentcnvYYset_column_ALREADY_DEFINED
#else
#define yyset_column commentcnvYYset_column
#endif

#ifdef yywrap
#define commentcnvYYwrap_ALREADY_DEFINED
#else
#define yywrap commentcnvYYwrap
#endif

#ifdef yyalloc
#define commentcnvYYalloc_ALREADY_DEFINED
#else
#define yyalloc commentcnvYYalloc
#endif

#ifdef yyrealloc
#define commentcnvYYrealloc_ALREADY_DEFINED
#else
#define yyrealloc commentcnvYYrealloc
#endif

#ifdef yyfree
#define commentcnvYYfree_ALREADY_DEFINED
#else
#define yyfree commentcnvYYfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define commentcnvYYwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 100
#define YY_END_OF_BUFFER 101
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[634] =
    {   0,
        2,    2,   52,   52,   52,   52,   40,   40,   40,   40,
       79,   79,  101,   99,  100,  100,    2,   33,   99,  100,
        3,   33,   99,  100,   11,  100,   33,   99,  100,    9,
       33,   99,  100,   19,   33,   99,  100,   10,   33,   99,
      100,    2,   33,   99,  100,   33,   99,  100,    2,   33,
       99,  100,   33,   99,  100,    2,   33,   99,  100,    1,
        2,   33,   99,  100,   33,   99,  100,   46,   99,  100,
       47,  100,   45,   46,   99,  100,   46,   99,  100,   50,
       99,  100,   51,  100,   49,   50,   99,  100,   50,   99,
      100,   75,  100,   99,  100,   99,  100,   52,   61,   99,

      100,   55,  100,   61,   99,  100,   61,   99,  100,   53,
       61,   99,  100,   52,   61,   99,  100,   61,   99,  100,
       61,   99,  100,   61,   99,  100,   52,   61,   99,  100,
       61,   99,  100,   52,   61,   99,  100,   61,   99,  100,
       61,   99,  100,   61,   99,  100,   61,   99,  100,   40,
       43,   99,  100,   41,  100,   43,   99,  100,   43,   99,
      100,   40,   43,   99,  100,   43,   99,  100,   43,   99,
      100,   43,   99,  100,   35,   43,   99,  100,   36,   43,
       99,  100,   43,   99,  100,   40,   43,   99,  100,   43,
       99,  100,   79,   98,   99,  100,   80,  100,   78,   98,

       99,  100,   79,   98,   99,  100,   98,   99,  100,   79,
       98,   99,  100,   98,   99,  100,   79,   98,   99,  100,
       79,   98,   99,  100,   79,   98,   99,  100,   79,   98,
       99,  100,   87,   99,  100,   84,   87,   99,  100,   86,
      100,   92,   97,   99,  100,   94,  100,   97,   99,  100,
       93,   97,   99,  100,   95,   97,   99,  100,   96,   97,
       99,  100,   92,   97,   99,  100,   92,   97,   99,  100,
        2,    7,   22,   19,    2,    8,    2,    1,    2,   18,
        1,    2,    2,    2,    2,    2,    2,    1,    1,    2,
        1,    2,    1,    2,   31,   32,   44,   48,   52,   60,

       58,   59,   53,   53,   57,   52,   56,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       52,   52,   40,   40,   40,   39,   79,   80,   77,   79,
       79,   79,   79,   79,   79,   79,   79,   79,   84,   92,
       91,   92,   92,   92,    5,    7,    6,    8,    2,   20,
       21,    1,    1,    2,    2,    1,    2,   18,   18,   16,
    16397,    1,    1,    1,    2,    1,    2,    2,    2,    1,
        2,    1,    2,    1,    2,    1,    1,    1,    1,    2,
       67,   54,   81,   88,   89,   88,   88,   88,   29,   29,
       89,   88,   88,   88,   88,   88,   88,   88,   88,   88,

       52,   27,   27,   34,   42,   37,   37,   39,   76,   79,
       79,   27,   79,   27,   79,   92,16474,    4,   20,    1,
        1,    2,    1,    2,   17,   16,   16,16397,    1,    1,
        1,    2,    1,    1,    2,    2,    1,    2,    1,    2,
        1,    2,    1,    2,    1,    2,    1,   70,16453,16452,
    16457,16448,   62,   81,   81,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   52,   27,
       27,   37,   37,   79,   79,   27,   79,   27,   79, 8282,
       92, 8282,    1,    1,    1,    2,   16,    1,    2,    2,
        1,    1,    2,    1,    2,16456,16456,16455,16456,16458,

    16450,16450,   63,16450,16450, 8261, 8260, 8265, 8256,   88,
       88,   28,   28,   89,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   52,   79,   79,    1,    2,    1,    2,
        1,    1,    2,    1,    1,    1,    2,    1,    2, 8264,
     8263, 8266, 8258,   23,   82,   82,   82,   85,   82,   89,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       52,   79,   79,    1,    1,    1,    2,    1,    2,    1,
        1,    1,    1,    2,    1,    2,    1,    1,   65, 8264,
       65, 8258,   85,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   52,   25,   38,   79,   79,   12,   12,

       12,    1,    1,   65, 8263,   24,   88,   88,   88,   88,
       88,   88,   88,   88,   79,   15, 8205, 8205, 8205,   15,
       88,   83,   83,   89,   88,   30,   30,   89,   88,   26,
       88,   14,   16
    } ;

static const flex_int16_t yy_accept[644] =
    {   0,
        1,    1,    1,    2,    3,    3,    3,    3,    3,    3,
        3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
       13,   13,   13,   13,   13,   14,   16,   17,   21,   25,
       27,   30,   34,   38,   42,   46,   49,   53,   56,   60,
       65,   68,   71,   73,   77,   80,   83,   85,   89,   92,
       94,   96,   98,  102,  104,  107,  110,  114,  118,  121,
      124,  127,  131,  134,  138,  141,  144,  147,  150,  154,
      156,  159,  162,  166,  169,  172,  175,  179,  183,  186,
      190,  193,  197,  199,  203,  207,  210,  214,  217,  221,
      225,  229,  233,  236,  240,  242,  246,  248,  251,  255,

      259,  263,  267,  271,  272,  272,  273,  274,  274,  275,
      276,  276,  277,  277,  278,  278,  280,  281,  281,  281,
      283,  284,  285,  286,  287,  288,  289,  291,  293,  295,
      296,  297,  298,  299,  299,  299,  299,  299,  299,  300,
      301,  301,  302,  303,  303,  304,  305,  306,  307,  307,
      308,  308,  308,  308,  308,  309,  310,  311,  312,  313,
      314,  315,  316,  317,  318,  319,  320,  321,  322,  322,
      322,  323,  323,  323,  323,  323,  323,  324,  324,  324,
      325,  325,  325,  325,  325,  325,  326,  326,  327,  328,
      329,  330,  331,  331,  332,  333,  334,  335,  336,  337,

      338,  339,  340,  341,  342,  343,  344,  345,  345,  347,
      347,  347,  349,  350,  351,  352,  353,  355,  356,  358,
      359,  360,  360,  361,  361,  361,  362,  363,  363,  363,
      364,  366,  368,  369,  369,  370,  371,  372,  374,  376,
      377,  378,  379,  381,  381,  382,  382,  382,  383,  383,
      383,  383,  384,  385,  386,  387,  388,  389,  390,  392,
      393,  394,  395,  396,  397,  398,  399,  400,  401,  402,
      402,  402,  403,  404,  404,  405,  406,  406,  407,  408,
      409,  410,  411,  412,  414,  416,  418,  419,  420,  421,
      421,  422,  423,  423,  425,  426,  426,  427,  427,  427,

      428,  429,  430,  430,  431,  433,  434,  436,  436,  437,
      438,  439,  440,  441,  443,  445,  447,  448,  449,  449,
      449,  450,  451,  452,  453,  454,  454,  454,  454,  454,
      455,  456,  457,  458,  459,  460,  461,  462,  463,  464,
      465,  466,  467,  468,  469,  470,  470,  470,  471,  472,
      472,  472,  473,  474,  475,  476,  478,  480,  482,  483,
      484,  485,  487,  487,  487,  487,  487,  488,  488,  488,
      488,  488,  488,  489,  489,  490,  491,  491,  492,  493,
      494,  494,  496,  497,  498,  499,  500,  501,  502,  503,
      504,  504,  505,  506,  506,  507,  507,  508,  508,  509,

      509,  510,  510,  510,  510,  511,  512,  513,  515,  516,
      517,  518,  519,  520,  521,  522,  523,  524,  525,  525,
      525,  525,  525,  525,  525,  525,  525,  525,  525,  525,
      525,  525,  525,  526,  527,  528,  528,  528,  528,  528,
      528,  528,  528,  528,  528,  529,  529,  531,  531,  532,
      534,  535,  536,  538,  540,  540,  541,  541,  541,  541,
      541,  542,  542,  542,  542,  543,  543,  544,  544,  544,
      544,  545,  545,  545,  546,  547,  549,  551,  552,  553,
      554,  555,  556,  557,  558,  559,  560,  561,  562,  562,
      562,  562,  562,  562,  562,  562,  562,  562,  562,  562,

      562,  562,  562,  563,  564,  564,  564,  564,  564,  564,
      564,  564,  565,  566,  568,  570,  571,  572,  573,  575,
      577,  578,  579,  579,  579,  581,  581,  583,  583,  583,
      583,  584,  585,  586,  587,  588,  589,  590,  591,  592,
      593,  594,  595,  596,  596,  596,  596,  596,  596,  596,
      596,  596,  596,  596,  597,  598,  599,  600,  601,  602,
      602,  602,  602,  602,  602,  602,  602,  603,  604,  604,
      606,  607,  607,  608,  609,  610,  611,  612,  613,  614,
      615,  615,  615,  615,  615,  615,  615,  615,  615,  615,
      616,  617,  617,  618,  619,  620,  621,  622,  623,  625,

      626,  627,  629,  629,  629,  629,  629,  629,  629,  629,
      629,  629,  629,  630,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  632,  632,  632,  632,  632,  632,
      632,  632,  632,  632,  632,  632,  632,  632,  632,  632,
      632,  634,  634
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,    1,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       22,   22,   22,   22,   22,   23,   23,   24,   16,   25,
       16,   26,    1,   27,   28,   29,   30,   31,   32,   33,
       34,   34,   34,   34,   34,   35,   34,   34,   34,   36,
       34,   34,   34,   34,   37,   34,   34,   38,   34,   34,
       39,   40,   41,    1,   42,   43,   44,   45,   46,   47,

       48,   49,   34,   50,   51,   34,   52,   53,   54,   55,
       56,   36,   34,   57,   58,   59,   60,   61,   34,   62,
       63,   34,   64,   65,   66,   67,    1,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,

       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68
    } ;

static const YY_CHAR yy_meta[69] =
    {   0,
        1,    2,    3,    1,    4,    5,    6,    7,    1,    8,
        9,    8,    8,   10,   11,    7,   12,   13,   14,   15,
       15,   15,   15,    1,   16,    1,   17,   18,   18,   18,
       18,   18,   18,   19,   19,   18,   19,   19,    1,   20,
        1,   21,   22,   18,   18,   18,   18,   18,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   23,    8,   24,   25,   26
    } ;

static const flex_int16_t yy_base[727] =
    {   0,
     2032, 2016,    0,   45,   29,   30,    1,   31, 2015,   24,
       91,  158,   17,   18,  162,  166,  171,  177,  244,  173,
      312,  380,  170,  345, 2016, 4338, 4338,    0, 4338, 4338,
      161, 2008, 2006, 4338,  447, 1995,   56,   35,  477,  529,
       32, 4338, 4338, 4338,    0, 4338, 4338, 4338,    0,  189,
      327, 1991,    0,  195, 4338, 2002,   41,  589,   69, 1954,
      629,  692,    8,  355,  360, 1964, 1939,   46,    0, 4338,
     4338,   41,  339, 1986, 1956, 1960, 4338, 4338, 1935,  367,
     1982, 1997, 4338, 1979,  758, 1981,  825,    0,  892,  365,
      180,  315, 4338,    0, 4338,    0, 4338, 1974, 4338, 4338,

     4338,  395, 1973,    0, 1988, 4338, 1987, 1982, 4338,  958,
     1985, 4338, 1980,  997, 1974, 1027,  156,  337,  413,  459,
      419,  448,  156,  395, 1080, 1138,    0,  160,  186, 4338,
     4338, 4338, 4338,  424, 1959,  455, 1958,  316,    0, 4338,
      454, 4338, 4338, 1969,  147,  205, 4338, 1930,    0, 4338,
      208, 1946,  290,    0, 1908,  143,  269,  299,  466,  302,
      178,  128,  432,  425,  452,  266,   20,   36,  499,  296,
      512,  516, 1927, 1902, 1919, 1894,    0, 1905,  515,  518,
     1939,    9, 1895, 1905, 1880,  527, 1927,  371, 1941, 4338,
     4338, 1899, 1928, 1198, 1897,  483,  560,  370,  371,  422,

      500,    0,    0, 4338,  539, 1921,  529, 1936, 4338, 1932,
     1934, 4338, 1264,    0, 4338, 1294, 1337,  553,    0, 4338,
     1917, 1932, 4338, 1931,  528,  535,  586,  620,  692,  706,
      724,  381,  564,  602,  767, 1922, 1371, 1420, 1478,    0,
      340,  507,    0,  691, 1907, 1917,  550, 4338, 1906,    0,
      492,  213, 1859, 4338,  565,  586,  438, 4338, 4338,  524,
      553,  585,  516,  546,  508,  469,  569,  583,  593, 1866,
     1870, 1877, 1848, 1863, 4338, 4338, 1862, 1865, 1816, 4338,
     4338, 1830,  667,  608,  667,  709, 4338,    0,    0,  788,
     4338,  730,  771,  832, 4338, 1877,  720,  745, 1874,  793,

      718,    0,  918,  902,  961,  793,  836, 1008, 1033, 1865,
     1517, 1556, 1839,    0,    0,  854, 4338,  905, 1866, 1149,
     1870, 1869, 1868, 1867, 4338,  839,    0, 1851,  645,  738,
      775,  796,  798,  550, 1619,  775,  642,  589,  822,  751,
      784,  722,  814,  816, 1687, 1821, 1808, 1823, 1798, 1131,
      908, 1817, 1791, 1753, 1820,  738,  752,  912,    0, 1207,
     1224, 1275,  909, 1838,  881, 1853,  968, 1852,  987,  992,
      924, 1300,  862,  852,    0, 1000, 1818,    0, 1267,  926,
     1004, 1482, 1850, 1031, 1037,  843, 1845, 1840, 1192, 4338,
      977, 1298,  941, 1839, 4338, 1838, 4338, 1836, 4338, 1835,

     4338, 1819,    0,  959, 1887, 1009, 4338, 4338, 1014, 1023,
      937,  532,  851,  857,  987,  968, 1008, 1955, 1787, 1786,
     1760, 1755, 1760, 1768, 1766, 1750, 1760, 1753, 1749, 1748,
     1745, 1748, 2021, 2088, 1628, 1147,  815, 1160, 1782, 1215,
     1781, 1161,  999, 1356, 1228, 1232, 1696, 1063, 2145, 1762,
     1829,    0, 1896,    0, 1796, 4338, 1304, 1117, 1795, 1334,
     4338, 1147, 1790, 1788, 4338, 1787, 4338, 1489, 1213, 1786,
     1770, 1769, 1040, 4338, 1289, 4338, 4338, 1099, 1033, 1132,
      931, 1113,  753, 1221, 1107, 1172, 1249, 1294, 1349, 1729,
     1735, 1722, 1724, 1715, 1717, 1722, 1713, 1715, 1720, 1692,

     1704, 1695, 1202, 1306,    0, 1382, 1516,  368, 1349, 1293,
     1531, 1964, 2030, 2097,    0,    0, 1395, 2150, 2184,    0,
     2189, 4338, 1741, 1740, 4338, 1739, 4338, 1250, 1339, 1378,
     4338, 1169, 1005, 1281, 1331, 1277, 1301, 1325, 1292, 1347,
     1333, 1380, 4338, 1697, 1694, 1685, 1678, 1688, 1679, 1677,
     1687, 1674, 1677, 4338, 1401, 1381, 4338, 1555, 1658, 1652,
     1657, 1436,    0, 1666, 1707, 1509, 2223, 4338, 1718, 4338,
     4338, 1688, 1349, 2276, 1363, 1466, 1488, 2344, 1491, 1478,
     1655, 1648, 1645, 1642, 1618, 1623, 1621, 1630, 1610, 1524,
     4338, 1551, 4338, 1700, 1581, 1637, 1504, 4338, 4338, 1506,

     4338, 4338, 1650, 1542, 1542, 1539, 1517, 1460, 1444, 1436,
     1375, 1517, 1603, 4338, 1288, 1266, 1199, 1160, 1109, 1094,
     1034, 1020, 1364, 1517,  989,  928,  889,  834,  678, 1638,
      675,  482, 1661,  430, 1187,  125, 1666, 1639,   28,    6,
     4338, 4338, 2412, 2438, 2464, 2490, 2516, 2542, 2568, 2594,
     2620, 2646, 2672, 2698, 2724, 2750, 2776, 2802, 2818, 2844,
     2870, 2896, 2922, 2947, 2968, 2994, 3020, 3046, 3072, 3098,
     3124, 3139, 3148, 3159, 3182, 3208, 3234, 3252, 3271, 3297,
     3312, 3337, 3358, 3384, 3410, 3436, 3462, 3488, 3514, 3540,
     3566, 3581, 3596, 3612, 3637, 3644, 3667, 3693, 3719, 3745,

     3771, 3797, 3823, 3849, 3875, 1657, 1655, 3893, 3912, 3938,
     3964, 3990, 4016, 4042, 4068, 4094, 4109, 4124, 4140, 4166,
     4192, 4207, 4233, 4259, 4285, 4311
    } ;

static const flex_int16_t yy_def[727] =
    {   0,
      643,  643,  644,  644,  645,  645,  646,  646,  643,  643,
      642,   11,   11,   11,  647,  647,  647,  647,  642,   19,
      648,  648,  649,  649,  642,  642,  642,  650,  642,  642,
      651,  642,  642,  642,  652,  642,  650,  642,  650,  650,
      642,  642,  642,  642,  653,  642,  642,  642,  654,  642,
      642,  642,  655,  656,  642,  642,  657,  658,  642,  659,
      642,  658,  642,  655,  642,  642,  642,  642,  660,  642,
      642,  642,  660,  642,  642,  642,  642,  642,  642,  660,
      642,  661,  642,  642,  662,  642,  663,   61,  662,  661,
      661,  661,  642,  664,  642,  665,  642,  642,  642,  642,

      642,  665,  665,  650,  651,  642,  666,  642,  642,  652,
      667,  642,  668,  669,  670,  650,  642,  671,  642,  650,
      650,   39,  650,  650,  642,  642,   40,  650,  650,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  655,  642,
      656,  642,  642,  642,  657,  657,  642,   62,  672,  642,
      642,  659,  659,  673,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,   62,  642,  642,
      655,  642,  642,  642,  642,  642,  660,  642,  642,  660,
      642,  642,  642,  642,  642,  660,  642,  642,  661,  642,
      642,   89,  642,  663,  194,   89,  661,  661,  661,  661,

      661,  664,  665,  642,  665,  665,  665,  666,  642,  642,
      668,  642,  669,  675,  642,  642,  650,  650,  650,  642,
      642,  671,  642,  676,  671,  677,  642,  642,  642,  642,
      650,  650,  650,  642,  650,  678,  650,  642,  238,  126,
      642,  642,  650,  642,  679,  642,  680,  642,  672,  681,
      659,  682,  674,  642,  674,  674,  674,  642,  642,  674,
      674,  674,  674,  674,  674,  674,  674,  674,   62,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  194,   89,  661,  661,  683,  642,  675,  216,  642,
      642,  650,  642,  650,  642,  676,  642,  671,  684,  685,

      677,  216,  642,  642,  650,  642,  650,  642,  650,  678,
      650,  642,  237,  238,  239,  239,  642,  686,  642,  687,
      688,  689,  690,  691,  642,  642,  692,  693,  694,  642,
      695,  696,  696,  696,  696,  696,  696,  696,  696,  696,
      696,  696,  696,  696,  697,  642,  642,  642,  642,  642,
      642,  642,  642,  698,  699,  700,  700,  701,  702,  642,
      642,  650,  642,  642,  703,  704,  642,  705,  705,  642,
      705,  642,  642,  706,  311,  650,  707,  312,  708,  650,
      642,  239,  709,  709,  710,  709,  711,  712,  712,  642,
      642,  712,  712,  713,  642,  714,  642,  715,  642,  716,

      642,  717,  718,  719,  696,  696,  642,  642,  696,  696,
      696,  696,  696,  696,  696,  696,  696,  697,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  698,  699,  642,  642,  703,  642,  642,  642,
      642,  705,  706,  642,  650,  642,  650,  706,  708,  650,
      642,  449,  239,  239,  709,  642,  709,  709,  710,  710,
      642,  710,  720,  711,  642,  712,  642,  712,  712,  721,
      717,  722,  719,  642,  642,  642,  642,  696,  696,  696,
      696,  696,  696,  696,  696,  696,  696,  418,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,

      642,  642,  433,  434,  723,  723,  642,  703,  642,  642,
      705,  642,  642,  650,  650,  449,  708,  642,  650,  650,
      642,  642,  724,  720,  642,  721,  642,  722,  719,  642,
      642,  696,  696,  696,  696,  696,  696,  696,  696,  696,
      696,  418,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  433,  434,  642,  642,  642,  642,
      642,  703,  725,  725,  705,  705,  642,  642,  724,  642,
      642,  719,  696,  696,  696,  696,  696,  696,  696,  696,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  433,
      642,  703,  642,  642,  642,  705,  696,  642,  642,  696,

      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  703,  696,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  703,  696,  642,  642,  642,  642,  642,  703,
      642,  642,  703,  642,  703,  642,  703,  703,  726,  726,
      642,    0,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,

      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642
    } ;

static const flex_int16_t yy_nxt[4407] =
    {   0,
      642,   29,   30,   47,   29,   31,   32,   33,  641,  169,
       34,   48,  169,   35,  276,   29,   36,   37,   38,   39,
       40,   40,   40,   55,   55,   51,   50,  276,   51,   35,
      641,   43,   43,   47,  170,   44,   44,  642,  130,   41,
       49,   48,   52,   68,   68,   35,   29,   30,  117,   29,
       31,   32,   33,  118,  146,   34,   68,   68,   35,  147,
       29,   36,   37,   38,   39,   40,   40,   40,   45,   45,
       49,  131,  154,  268,   35,  116,  116,  116,  116,  148,
       55,   55,  150,  254,   41,  154,  269,  151,  178,  179,
       35,   53,   53,   54,   53,   55,   55,   56,   53,   53,

       53,   53,   53,   53,   57,   58,   53,   58,   58,   59,
       58,   58,   58,   58,   53,   60,   53,   61,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   53,
       61,   53,   58,   55,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   62,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   63,   53,   53,   55,   58,   64,
      642,  220,   65,  106,   70,  642,  107,   73,   70,  221,
       73,  262,   97,   70,   90,  232,  232,   90,   80,   70,
       71,   80,  190,   98,   74,  107,  107,  275,   72,   71,
      134,  254,   72,  134,  243,   81,  141,   75,  255,  141,

       66,   72,  142,   75,   71,   72,  254,  135,   71,   99,
       75,  143,  243,   76,  330,   91,   75,  330,  146,   76,
      128,  150,  200,  147,   67,   71,  151,   71,   71,   71,
      261,   71,   71,  100,   77,  101,   78,   79,  128,   92,
       77,  254,   78,   79,   82,   82,   83,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   84,   85,   82,
       85,   85,   86,   85,   85,   85,   85,   82,   87,   82,
       88,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   82,   88,   82,   85,   82,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   89,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   82,   82,   82,
       82,   85,   93,  267,   95,   93,  250,  190,   93,   93,
       93,  245,   93,  246,  256,   93,   93,   93,  136,  254,
       93,  136,  254,  251,  247,   93,   93,   93,   93,  223,
      180,  270,  224,  180,  225,  137,  102,   97,  271,  102,
       93,   93,   93,  257,   93,  226,  171,  181,   98,  172,
      260,  172,  254,  103,  172,  254,  197,  190,  186,  197,
      223,  186,  190,  190,  317,   93,  280,   93,   93,   93,
       93,  201,   95,   93,   99,  187,   93,   93,   93,  280,
       93,  306,  317,   93,   93,   93,  205,  173,   93,  205,

      307,  307,  173,   93,   93,   93,   93,  198,  100,  233,
      101,  234,  200,  206,  235,  235,  235,  235,   93,   93,
       93,  174,   93,  119,  190,  134,  174,  562,  134,  230,
      227,  199,  228,  228,  228,  228,  120,  201,  231,  231,
      231,  122,  135,   93,  229,   93,   93,   93,  111,  112,
      124,  111,  113,  111,  111,  141,  136,  111,  141,  136,
      229,  142,  111,  111,  284,  111,  124,  122,  122,  122,
      143,  114,  114,  137,  258,  263,  104,  258,  116,  116,
      116,  116,  636,  265,  336,  104,  111,  119,  254,  264,
      218,  219,  104,  219,  120,  254,  121,  121,  121,  122,

      169,  254,  190,  169,  258,  123,  218,  219,  124,  104,
      266,  219,  342,  171,  125,  254,  172,  172,  250,  180,
      172,  123,  180,  275,  124,  170,  192,  275,  186,  259,
      223,  186,  254,  283,  286,  298,  181,  300,  125,  126,
      205,  241,  329,  205,  275,  187,  120,  286,  127,  127,
      127,  127,  325,  301,  173,  275,  341,  206,  173,  241,
      124,  197,  190,  128,  197,  129,  285,  292,  326,  293,
      340,  254,  294,  294,  294,  294,  124,  337,  174,  254,
      275,  128,  174,  235,  235,  235,  235,  254,  129,  139,
      139,  335,  139,  482,  406,  254,  139,  139,  139,  139,

      139,  139,  198,  338,  139,  302,  302,  302,  302,  254,
      190,  332,  139,  254,  139,  149,  254,  290,  291,  333,
      291,  303,  303,  303,  303,  343,  199,  139,  254,  139,
      119,  334,  254,  290,  291,  344,  148,  227,  291,  228,
      228,  228,  228,  339,  335,  345,  254,  411,  254,  254,
      356,  229,  254,  139,  139,  154,  155,  155,  155,  155,
      155,  155,  155,  155,  155,  155,  155,  229,  154,  190,
      155,  250,  155,  155,  156,  157,  158,  159,  160,  161,
      155,  162,  163,  155,  155,  164,  165,  155,  155,  166,
      167,  155,  139,  139,  410,  139,  318,  404,  319,  139,

      139,  139,  139,  139,  139,  254,  234,  139,  234,  320,
      192,  303,  303,  303,  303,  139,  230,  139,  149,  355,
      300,  363,  359,  227,  363,  304,  304,  304,  228,  634,
      139,  275,  139,  357,  230,  168,  301,  229,  364,  330,
      190,  120,  330,  305,  305,  305,  122,  223,  359,  294,
      294,  294,  294,  229,  190,  124,  139,  139,  189,  189,
      190,  189,  189,  189,  189,  189,  189,  189,  189,  189,
      189,  124,  359,  189,  359,  365,  330,  308,  415,  330,
      356,  189,  189,  189,  149,  254,  309,  309,  309,  309,
      360,  360,  360,  360,  369,  370,  189,  369,  189,  219,

      189,  219,  293,  306,  293,  537,  413,  360,  360,  360,
      360,  371,  373,  373,  254,  219,  254,  223,  357,  219,
      409,  189,  189,  189,  189,  189,  189,  190,  189,  189,
      189,  189,  189,  189,  189,  189,  189,  189,  254,  414,
      189,  325,  361,  335,  405,  456,  306,  254,  189,  189,
      189,  362,  362,  362,  362,  307,  307,  326,  416,  254,
      508,  254,  374,  189,  219,  189,  219,  189,  380,  412,
      381,  417,  306,  382,  382,  382,  382,  254,  195,  254,
      219,  373,  373,  223,  219,  254,  632,  444,  189,  189,
      189,  189,  189,  189,  190,  189,  189,  189,  189,  189,

      189,  189,  189,  189,  189,  483,  384,  189,  463,  384,
      363,  484,  230,  363,  254,  189,  189,  189,  149,  227,
      254,  304,  304,  304,  228,  359,  370,  364,  308,  385,
      189,  386,  189,  229,  189,  196,  437,  372,  372,  372,
      372,  275,  442,  467,  386,  450,  450,  450,  450,  229,
      291,  359,  291,  429,  430,  189,  189,  189,  189,  111,
      112,  431,  111,  111,  111,  111,  291,  432,  111,  438,
      291,  230,  438,  111,  111,  359,  111,  359,  120,  390,
      305,  305,  305,  122,  481,  250,  439,  535,  369,  370,
      275,  369,  124,  440,  254,  391,  440,  111,  211,  212,

      254,  211,  211,  211,  211,  371,  470,  211,  124,  374,
      441,  486,  211,  211,  445,  211,  446,  473,  308,  447,
      447,  447,  447,  451,  451,  451,  451,  372,  372,  372,
      372,  254,  457,  456,  444,  457,  211,  216,  460,  461,
      291,  460,  291,  308,  631,  485,  217,  217,  217,  217,
      254,  574,  309,  309,  309,  309,  291,  458,  218,  219,
      291,  219,  487,  462,  478,  219,  250,  219,  254,  479,
      458,  254,  254,  374,  218,  219,  462,  254,  480,  219,
      104,  219,  275,  104,  629,  219,  254,  533,  104,  104,
      236,  104,  104,  104,  104,  529,  254,  237,  444,  238,

      238,  238,  238,  104,  104,  104,  104,  238,  238,  238,
      238,  238,  238,  239,  239,  239,  239,  239,  104,  456,
      104,  104,  104,  238,  238,  238,  238,  238,  238,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  104,  104,  104,  104,  104,  126,  461,
      389,  390,  505,  389,  532,  227,  275,  240,  240,  240,
      240,  438,  254,  370,  438,  506,  539,  391,  536,  229,
      254,  275,  241,  392,  242,  393,  254,  421,  439,  511,
      422,  423,  463,  424,  425,  229,  534,  426,  393,  223,
      241,  427,  428,  468,  467,  254,  468,  242,  189,  189,

      190,  189,  189,  189,  189,  189,  189,  189,  189,  189,
      189,  507,  523,  189,  628,  467,  440,  361,  469,  440,
      573,  189,  189,  189,  250,  511,  435,  435,  435,  435,
      540,  469,  254,  441,  361,  254,  189,  637,  189,  291,
      189,  291,  627,  435,  435,  435,  435,  447,  447,  447,
      447,  512,  512,  512,  512,  291,  291,  555,  291,  291,
      194,  189,  189,  189,  189,  211,  212,  403,  211,  211,
      211,  211,  291,  538,  211,  571,  291,  236,  470,  211,
      211,  381,  211,  381,  254,  361,  449,  449,  449,  449,
      530,  531,  530,  530,  362,  362,  362,  362,  563,  468,

      467,  541,  468,  211,  216,  457,  456,  219,  457,  219,
      308,  563,  254,  289,  289,  289,  289,  542,  626,  372,
      372,  372,  372,  219,  469,  290,  291,  219,  291,  556,
      458,  577,  291,  575,  291,  460,  461,  469,  460,  625,
      254,  290,  291,  458,  254,  579,  291,  216,  291,  148,
      543,  543,  291,  543,  563,  254,  217,  217,  217,  217,
      462,  192,  572,  578,  254,  250,  223,  564,  218,  219,
      446,  219,  446,  462,  576,  512,  512,  512,  512,  530,
      531,  530,  530,  558,  218,  219,  558,  578,  254,  219,
      311,  311,  311,  311,  254,  578,  254,  580,  311,  311,

      311,  311,  311,  311,  597,  236,  642,  642,  559,  642,
      254,  642,  254,  507,  311,  311,  311,  311,  311,  311,
      104,  559,  630,  104,  590,  578,  254,  622,  104,  104,
      312,  104,  104,  104,  104,  148,  192,  313,  223,  314,
      314,  314,  314,  104,  104,  104,  104,  314,  314,  314,
      314,  314,  314,  315,  315,  316,  315,  315,  104,  194,
      104,  104,  104,  314,  314,  314,  314,  314,  314,  315,
      315,  315,  315,  315,  315,  315,  315,  315,  315,  315,
      315,  315,  315,  104,  104,  104,  104,  104,  236,  592,
      468,  467,  452,  468,  621,  104,  620,  315,  315,  315,

      315,  453,  453,  453,  453,  315,  315,  315,  315,  315,
      315,  370,  619,  315,  454,  469,  454,  560,  578,  223,
      560,  315,  315,  315,  315,  315,  315,  374,  469,  254,
      454,  578,  565,  370,  454,  565,  375,  375,  375,  375,
      600,  254,  561,  335,  375,  375,  375,  375,  375,  375,
      642,  254,  376,  223,  254,  561,  560,  566,  613,  560,
      375,  375,  375,  375,  375,  375,  312,  254,  578,  254,
      566,  623,  618,  377,  596,  378,  378,  378,  378,  578,
      254,  561,  194,  378,  378,  378,  378,  378,  378,  310,
      310,  379,  310,  310,  561,  617,  616,  615,  612,  378,

      378,  378,  378,  378,  378,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  310,  310,  310,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  361,  370,
      223,  223,  407,  407,  407,  407,  591,  435,  435,  435,
      435,  614,  614,  560,  614,  624,  560,  407,  407,  407,
      291,  407,  291,  223,  611,  443,  254,  594,  223,  448,
      594,  443,  448,  610,  443,  609,  291,  608,  561,  607,
      291,  633,  408,  407,  407,  407,  407,  139,  139,  606,
      139,  561,  595,  639,  139,  139,  139,  139,  139,  139,

      605,  560,  139,  604,  560,  595,  513,  603,  565,  370,
      139,  565,  139,  149,  642,  514,  514,  514,  514,  635,
      570,  638,  591,  591,  554,  139,  561,  139,  515,  589,
      515,  588,  587,  566,  586,  585,  584,  583,  582,  561,
      581,  527,  525,  570,  515,  418,  566,  554,  515,  554,
      554,  139,  139,  189,  189,  190,  189,  189,  189,  189,
      189,  189,  189,  189,  189,  189,  553,  552,  189,  551,
      550,  549,  518,  548,  547,  546,  189,  189,  189,  250,
      545,  519,  519,  519,  519,  544,  403,  327,  527,  467,
      465,  189,  525,  189,  520,  189,  520,  461,  456,  510,

      509,  502,  501,  500,  499,  433,  498,  497,  496,  495,
      520,  494,  493,  492,  520,  491,  189,  189,  189,  189,
      189,  189,  190,  189,  189,  189,  189,  189,  189,  189,
      189,  189,  189,  490,  489,  189,  327,  401,  399,  518,
      397,  395,  467,  189,  189,  189,  149,  465,  521,  521,
      521,  521,  456,  444,  370,  367,  436,  353,  189,  352,
      189,  522,  189,  522,  349,  348,  420,  419,  403,  401,
      399,  397,  395,  387,  376,  236,  367,  522,  434,  297,
      354,  522,  353,  189,  189,  189,  189,  474,  475,  476,
      475,  475,  474,  474,  474,  474,  474,  474,  474,  474,

      474,  474,  474,  474,  474,  474,  452,  352,  351,  350,
      474,  474,  474,  474,  349,  453,  453,  453,  453,  348,
      347,  346,  254,  327,  323,  474,  474,  474,  454,  474,
      454,  322,  236,  297,  223,  295,  212,  287,  209,  207,
      282,  281,  192,  190,  454,  188,  279,  278,  454,  277,
      477,  474,  474,  474,  474,  139,  139,  182,  139,  274,
      273,  272,  139,  139,  139,  139,  139,  139,  176,  175,
      139,  254,  250,  148,  513,  248,  138,  244,  139,  215,
      139,  149,  212,  567,  567,  567,  567,  112,  210,  209,
      106,  207,  204,  139,  193,  139,  568,  191,  568,  190,

      188,  185,  184,  183,  182,  176,  175,  153,  144,  138,
      488,  115,  568,  109,  108,  642,  568,   50,   27,  139,
      139,  189,  189,  190,  189,  189,  189,  189,  189,  189,
      189,  189,  189,  189,   27,  642,  189,  642,  642,  642,
      513,  642,  642,  642,  189,  189,  189,  250,  642,  567,
      567,  567,  567,  642,  642,  642,  642,  642,  642,  189,
      642,  189,  568,  189,  568,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  568,  503,
      642,  642,  568,  642,  189,  189,  189,  189,  189,  189,
      190,  189,  189,  189,  189,  189,  189,  189,  189,  189,

      189,  642,  642,  189,  642,  642,  642,  513,  642,  642,
      642,  189,  189,  189,  149,  642,  514,  514,  514,  514,
      642,  642,  642,  642,  642,  642,  189,  642,  189,  515,
      189,  515,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  504,  642,  515,  642,  642,  642,  515,
      642,  189,  189,  189,  189,  452,  642,  642,  642,  642,
      518,  642,  642,  642,  516,  516,  516,  516,  642,  521,
      521,  521,  521,  642,  642,  642,  642,  517,  642,  517,
      642,  642,  522,  642,  522,  642,  642,  642,  642,  642,
      642,  642,  642,  517,  518,  642,  642,  517,  522,  518,

      642,  642,  522,  519,  519,  519,  519,  642,  521,  521,
      521,  521,  642,  642,  642,  642,  520,  642,  520,  642,
      642,  522,  642,  522,  642,  642,  642,  642,  642,  642,
      642,  642,  520,  513,  642,  642,  520,  522,  642,  642,
      642,  522,  567,  567,  567,  567,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  568,  642,  568,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  568,  642,  642,  642,  568,  598,  598,  598,  598,
      598,  598,  598,  598,  598,  598,  598,  598,  598,  598,
      598,  598,  598,  598,  598,  642,  642,  642,  642,  598,

      598,  598,  598,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  598,  598,  598,  642,  598,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  599,
      598,  598,  598,  598,  601,  601,  601,  601,  601,  601,
      601,  601,  601,  601,  601,  601,  601,  601,  601,  601,
      601,  601,  601,  642,  642,  642,  642,  601,  601,  601,
      601,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  601,  601,  601,  642,  601,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,

      642,  642,  642,  642,  642,  642,  642,  602,  601,  601,
      601,  601,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   26,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,

       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   94,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   94,   94,   94,   94,   94,   94,   94,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,  104,  642,  642,  642,  642,  642,

      642,  104,  642,  104,  104,  642,  104,  642,  104,  104,
      104,  104,  104,  642,  104,  104,  104,  104,  104,  104,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
      105,  105,  105,  105,  105,  105,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  132,  132,  642,  132,  132,  132,  132,  132,
      132,  132,  132,  132,  132,  132,  132,  132,  132,  132,
      132,  132,  132,  132,  132,  132,  132,  132,  133,  133,

      642,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  139,  139,  642,  642,  642,  642,
      139,  139,  139,  642,  139,  139,  139,  642,  139,  642,
      642,  139,  139,  642,  139,  642,  642,  139,  642,  139,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  140,  140,  145,  145,  642,  145,
      145,  642,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  642,  145,  145,  642,  145,  145,  642,  145,

      145,  145,  148,  148,  642,  642,  642,  642,  148,  148,
      148,  642,  148,  148,  148,  642,  148,  642,  148,  148,
      148,  642,  148,  642,  642,  148,  642,  148,  152,  152,
      152,  642,  152,  642,  642,  152,  152,  642,  152,  642,
      642,  642,  642,  152,  177,  177,  642,  177,  177,  177,
      177,  177,  177,  177,  177,  177,  177,  642,  177,  177,
      642,  177,  177,  642,  177,  642,  642,  642,  642,  177,
      189,  189,  189,  189,  189,  189,  189,  189,  189,  642,
      189,  189,  189,  642,  189,  189,  642,  189,  189,  642,
      189,  189,  189,  189,  189,  189,  192,  192,  192,  192,

      192,  192,  192,  192,  192,  642,  192,  192,  192,  642,
      192,  192,  192,  192,  192,  642,  192,  192,  192,  192,
      192,  192,  194,  194,  194,  194,  194,  194,  194,  194,
      194,  642,  194,  194,  194,  642,  194,  194,  642,  194,
      194,  642,  194,  194,  194,  194,  194,  194,  202,  642,
      202,  202,  642,  642,  202,  642,  642,  642,  202,  202,
      642,  202,  642,  642,  202,  202,  642,  202,  203,  203,
      642,  203,  203,  203,  203,  203,  203,  642,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  642,  203,  203,
      642,  642,  203,  203,  208,  208,  208,  208,  208,  208,

      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  213,  213,  214,  214,

      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  222,  222,  222,  222,
      249,  642,  642,  249,  642,  642,  249,  249,  642,  249,
      642,  642,  642,  642,  249,  252,  252,  642,  252,  642,
      642,  642,  252,  253,  642,  642,  253,  253,  642,  253,
      642,  253,  288,  288,  642,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,

      288,  288,  288,  288,  288,  288,  288,  288,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      310,  642,  642,  642,  642,  642,  310,  642,  642,  310,
      310,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  324,  324,  324,

      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  328,  642,  642,  328,  642,  642,  328,
      328,  642,  328,  642,  642,  642,  642,  328,  331,  642,
      331,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  331,  642,  642,  331,  331,  642,  331,  358,  358,
      642,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  366,  366,  366,  366,  366,  366,
      366,  366,  366,  366,  366,  366,  366,  366,  366,  366,

      366,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      368,  368,  368,  368,  368,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  368,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  368,  368,  383,  383,  642,  383,
      383,  383,  383,  383,  383,  383,  383,  383,  383,  383,
      383,  383,  383,  383,  383,  383,  383,  383,  383,  383,
      383,  383,  388,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  388,  388,  388,  388,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  396,  396,  396,  396,  396,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,  398,  398,  398,  398,  398,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  402,  642,  642,  402,  642,  642,  402,  402,

      642,  402,  642,  642,  642,  642,  402,  328,  328,  642,
      328,  642,  642,  328,  328,  642,  328,  642,  642,  642,
      642,  328,  152,  152,  152,  642,  152,  642,  152,  152,
      152,  642,  152,  642,  642,  642,  642,  152,  331,  642,
      331,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  331,  642,  642,  331,  331,  642,  331,  253,  642,
      642,  253,  253,  642,  253,  642,  253,  148,  148,  642,
      642,  642,  642,  148,  148,  148,  642,  148,  148,  148,
      642,  148,  642,  148,  148,  148,  642,  148,  642,  642,
      148,  642,  148,  194,  194,  194,  194,  194,  194,  194,

      194,  194,  642,  194,  194,  194,  642,  194,  194,  194,
      194,  194,  642,  194,  194,  194,  194,  194,  194,  192,
      192,  192,  192,  192,  192,  192,  192,  192,  642,  192,
      192,  192,  642,  192,  192,  192,  192,  192,  642,  192,
      192,  192,  192,  192,  192,  189,  189,  189,  189,  189,
      189,  189,  189,  189,  642,  189,  189,  189,  642,  189,
      189,  642,  189,  189,  642,  189,  189,  189,  189,  189,
      189,  358,  358,  642,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  359,  359,  642,

      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  222,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  222,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  222,  222,  222,  366,
      366,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      366,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      366,  366,  366,  366,  366,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  368,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  368,  368,  368,  368,  368,  368,

      368,  310,  642,  310,  310,  642,  642,  310,  642,  642,
      310,  310,  455,  455,  455,  455,  455,  455,  455,  455,
      455,  455,  455,  455,  455,  455,  455,  455,  455,  455,
      455,  455,  455,  455,  455,  455,  455,  455,  459,  459,
      459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
      459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
      459,  459,  459,  459,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      466,  466,  466,  466,  466,  466,  466,  466,  466,  466,

      466,  466,  466,  466,  466,  466,  466,  466,  466,  466,
      466,  466,  466,  466,  466,  466,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  396,  396,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  396,  396,  396,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,  398,  398,  398,  400,  400,  400,  400,  400,  400,

      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      471,  471,  642,  471,  642,  642,  471,  471,  642,  471,
      642,  642,  642,  642,  471,  472,  642,  642,  472,  642,
      642,  472,  472,  642,  472,  642,  642,  642,  642,  472,
      152,  152,  152,  642,  152,  642,  152,  152,  152,  642,
      152,  642,  642,  642,  642,  152,  524,  524,  524,  524,
      524,  524,  524,  524,  524,  524,  524,  524,  524,  524,
      524,  524,  524,  524,  524,  524,  524,  524,  524,  524,
      524,  524,  526,  526,  526,  526,  526,  526,  526,  526,

      526,  526,  526,  526,  526,  526,  526,  526,  526,  526,
      526,  526,  526,  526,  526,  526,  526,  526,  528,  528,
      642,  528,  642,  642,  528,  528,  642,  528,  642,  642,
      642,  642,  528,  557,  557,  557,  557,  557,  557,  557,
      557,  557,  557,  557,  557,  557,  642,  557,  557,  557,
      557,  557,  557,  557,  557,  557,  557,  557,  557,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  593,  593,  593,  593,  593,
      593,  593,  593,  593,  593,  593,  593,  593,  642,  593,

      593,  593,  593,  593,  593,  593,  593,  593,  593,  593,
      593,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,   25,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,

      642,  642,  642,  642,  642,  642
    } ;

static const flex_int16_t yy_chk[4407] =
    {   0,
        0,    3,    3,    7,    3,    3,    3,    3,  640,   63,
        3,    7,   63,    3,  182,    3,    3,    3,    3,    3,
        3,    3,    3,   13,   14,   10,   10,  182,   10,    3,
      639,    5,    6,    8,   63,    5,    6,    0,   41,    3,
        7,    8,   10,   13,   14,    3,    4,    4,   38,    4,
        4,    4,    4,   38,   57,    4,   13,   14,    4,   57,
        4,    4,    4,    4,    4,    4,    4,    4,    5,    6,
        8,   41,   68,  167,    4,   37,   37,   37,   37,  168,
       13,   14,   59,  167,    4,   68,  168,   59,   72,   72,
        4,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   12,
      145,  117,   12,   31,   15,  145,   31,   16,   16,  117,
       16,  162,   23,   17,   20,  123,  123,   20,   18,   18,
       15,   18,   91,   23,   16,   31,   31,  636,   15,   17,
       50,  162,   16,   50,  128,   18,   54,   17,  156,   54,

       12,   15,   54,   18,   15,   16,  156,   50,   16,   23,
       17,   54,  128,   17,  252,   20,   18,  252,  146,   18,
      129,  151,   91,  146,   12,   15,  151,   15,   15,   16,
      161,   16,   16,   23,   17,   23,   17,   17,  129,   20,
       18,  161,   18,   18,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   21,  166,   21,   21,  153,   92,   21,   21,
       21,  138,   21,  138,  157,   21,   21,   21,   51,  166,
       21,   51,  157,  153,  138,   21,   21,   21,   21,  118,
       73,  170,  118,   73,  118,   51,   24,   24,  170,   24,
       21,   21,   21,  158,   21,  118,   64,   73,   24,   64,
      160,   65,  158,   24,   65,  160,   90,   90,   80,   90,
      508,   80,  198,  199,  241,   21,  188,   21,   21,   21,
       22,   92,   22,   22,   24,   80,   22,   22,   22,  188,
       22,  232,  241,   22,   22,   22,  102,   64,   22,  102,

      232,  232,   65,   22,   22,   22,   22,   90,   24,  124,
       24,  124,  198,  102,  124,  124,  124,  124,   22,   22,
       22,   64,   22,  119,  200,  134,   65,  508,  134,  121,
      119,   90,  119,  119,  119,  119,  121,  199,  121,  121,
      121,  121,  134,   22,  119,   22,   22,   22,   35,   35,
      121,   35,   35,   35,   35,  141,  136,   35,  141,  136,
      119,  141,   35,   35,  200,   35,  121,  122,  122,  122,
      141,   35,   35,  136,  159,  163,  122,  159,  120,  120,
      120,  120,  634,  164,  257,  122,   35,   39,  164,  163,
      120,  120,  122,  120,   39,  163,   39,   39,   39,   39,

      169,  257,  201,  169,  159,   39,  120,  120,   39,  122,
      165,  120,  266,  171,   39,  165,  171,  172,  251,  180,
      172,   39,  180,  179,   39,  169,  196,  179,  186,  159,
      225,  186,  266,  196,  207,  225,  180,  226,   39,   40,
      205,  242,  251,  205,  632,  186,   40,  207,   40,   40,
       40,   40,  247,  226,  171,  179,  265,  205,  172,  242,
       40,  197,  197,   40,  197,   40,  201,  218,  247,  218,
      263,  265,  218,  218,  218,  218,   40,  260,  171,  263,
      179,   40,  172,  233,  233,  233,  233,  260,   40,   58,
       58,  264,   58,  412,  334,  412,   58,   58,   58,   58,

       58,   58,  197,  261,   58,  227,  227,  227,  227,  264,
      284,  255,   58,  334,   58,   58,  261,  227,  227,  255,
      227,  234,  234,  234,  234,  267,  197,   58,  255,   58,
      228,  256,  267,  227,  227,  268,  269,  228,  227,  228,
      228,  228,  228,  262,  256,  269,  268,  338,  262,  256,
      284,  228,  338,   58,   58,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,  228,   61,  285,
       61,  329,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   62,   62,  337,   62,  244,  329,  244,   62,

       62,   62,   62,   62,   62,  337,  229,   62,  229,  244,
      283,  229,  229,  229,  229,   62,  230,   62,   62,  283,
      301,  297,  286,  230,  297,  230,  230,  230,  230,  631,
       62,  629,   62,  285,  231,   62,  301,  230,  297,  330,
      356,  231,  330,  231,  231,  231,  231,  298,  286,  292,
      292,  292,  292,  230,  357,  231,   62,   62,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,  231,  286,   85,  286,  298,  331,  235,  342,  331,
      356,   85,   85,   85,   85,  342,  235,  235,  235,  235,
      293,  293,  293,  293,  300,  300,   85,  300,   85,  235,

       85,  235,  290,  306,  290,  483,  340,  290,  290,  290,
      290,  300,  306,  306,  340,  235,  483,  437,  357,  235,
      336,   85,   85,   85,   85,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,  336,  341,
       87,  326,  294,  332,  333,  386,  307,  341,   87,   87,
       87,  294,  294,  294,  294,  307,  307,  326,  343,  332,
      437,  333,  374,   87,  294,   87,  294,   87,  316,  339,
      316,  344,  373,  316,  316,  316,  316,  343,   87,  344,
      294,  373,  373,  365,  294,  339,  628,  374,   87,   87,
       87,   87,   89,   89,   89,   89,   89,   89,   89,   89,

       89,   89,   89,   89,   89,  413,  318,   89,  386,  318,
      363,  414,  304,  363,  413,   89,   89,   89,   89,  304,
      414,  304,  304,  304,  304,  358,  371,  363,  303,  318,
       89,  318,   89,  304,   89,   89,  365,  303,  303,  303,
      303,  627,  371,  393,  318,  380,  380,  380,  380,  304,
      303,  358,  303,  351,  351,   89,   89,   89,   89,  110,
      110,  351,  110,  110,  110,  110,  303,  351,  110,  367,
      303,  305,  367,  110,  110,  358,  110,  358,  305,  391,
      305,  305,  305,  305,  411,  404,  367,  481,  369,  369,
      626,  369,  305,  370,  481,  391,  370,  110,  114,  114,

      411,  114,  114,  114,  114,  369,  393,  114,  305,  443,
      370,  416,  114,  114,  376,  114,  376,  404,  308,  376,
      376,  376,  376,  381,  381,  381,  381,  308,  308,  308,
      308,  416,  384,  384,  443,  384,  114,  116,  385,  385,
      308,  385,  308,  309,  625,  415,  116,  116,  116,  116,
      415,  533,  309,  309,  309,  309,  308,  384,  116,  116,
      308,  116,  417,  385,  406,  309,  473,  309,  533,  409,
      384,  417,  406,  448,  116,  116,  385,  409,  410,  116,
      125,  309,  622,  125,  621,  309,  410,  479,  125,  125,
      125,  125,  125,  125,  125,  473,  479,  125,  448,  125,

      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  458,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  126,  462,
      320,  320,  436,  320,  478,  126,  620,  126,  126,  126,
      126,  438,  478,  442,  438,  436,  485,  320,  482,  126,
      485,  619,  126,  320,  126,  320,  482,  350,  438,  442,
      350,  350,  458,  350,  350,  126,  480,  350,  320,  635,
      126,  350,  350,  389,  389,  480,  389,  126,  194,  194,

      194,  194,  194,  194,  194,  194,  194,  194,  194,  194,
      194,  436,  462,  194,  618,  469,  440,  360,  389,  440,
      532,  194,  194,  194,  194,  442,  360,  360,  360,  360,
      486,  389,  532,  440,  361,  486,  194,  635,  194,  360,
      194,  360,  617,  361,  361,  361,  361,  445,  445,  445,
      445,  446,  446,  446,  446,  360,  361,  503,  361,  360,
      503,  194,  194,  194,  194,  213,  213,  528,  213,  213,
      213,  213,  361,  484,  213,  528,  361,  379,  469,  213,
      213,  379,  213,  379,  484,  362,  379,  379,  379,  379,
      475,  475,  475,  475,  362,  362,  362,  362,  510,  392,

      392,  487,  392,  213,  216,  457,  457,  362,  457,  362,
      372,  510,  487,  216,  216,  216,  216,  488,  616,  372,
      372,  372,  372,  362,  392,  216,  216,  362,  216,  504,
      457,  536,  372,  534,  372,  460,  460,  392,  460,  615,
      536,  216,  216,  457,  534,  539,  216,  217,  372,  488,
      489,  489,  372,  489,  509,  539,  217,  217,  217,  217,
      460,  504,  529,  537,  537,  529,  623,  509,  217,  217,
      444,  217,  444,  460,  535,  444,  444,  444,  444,  530,
      530,  530,  530,  506,  217,  217,  506,  538,  538,  217,
      237,  237,  237,  237,  535,  541,  541,  540,  237,  237,

      237,  237,  237,  237,  573,  517,  542,  556,  506,  517,
      540,  517,  573,  509,  237,  237,  237,  237,  237,  237,
      238,  506,  623,  238,  555,  575,  575,  611,  238,  238,
      238,  238,  238,  238,  238,  542,  556,  238,  562,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  555,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  239,  562,
      468,  468,  382,  468,  610,  239,  609,  239,  239,  239,

      239,  382,  382,  382,  382,  239,  239,  239,  239,  239,
      239,  566,  608,  239,  382,  468,  382,  507,  576,  612,
      507,  239,  239,  239,  239,  239,  239,  311,  468,  576,
      382,  580,  511,  511,  382,  511,  311,  311,  311,  311,
      577,  580,  507,  579,  311,  311,  311,  311,  311,  311,
      590,  577,  311,  592,  579,  507,  558,  511,  597,  558,
      311,  311,  311,  311,  311,  311,  312,  597,  600,  600,
      511,  612,  607,  312,  566,  312,  312,  312,  312,  624,
      624,  558,  590,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  558,  606,  605,  604,  592,  312,

      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  435,  596,
      630,  638,  335,  335,  335,  335,  595,  435,  435,  435,
      435,  603,  603,  560,  603,  613,  560,  335,  335,  335,
      435,  335,  435,  633,  589,  706,  613,  564,  637,  707,
      564,  706,  707,  588,  706,  587,  435,  586,  560,  585,
      435,  630,  335,  335,  335,  335,  335,  345,  345,  584,
      345,  560,  564,  638,  345,  345,  345,  345,  345,  345,

      583,  594,  345,  582,  594,  564,  447,  581,  565,  565,
      345,  565,  345,  345,  572,  447,  447,  447,  447,  633,
      569,  637,  561,  559,  553,  345,  594,  345,  447,  552,
      447,  551,  550,  565,  549,  548,  547,  546,  545,  594,
      544,  526,  524,  523,  447,  345,  565,  502,  447,  501,
      500,  345,  345,  354,  354,  354,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  499,  498,  354,  497,
      496,  495,  450,  494,  493,  492,  354,  354,  354,  354,
      491,  450,  450,  450,  450,  490,  472,  471,  470,  466,
      464,  354,  463,  354,  450,  354,  450,  459,  455,  441,

      439,  432,  431,  430,  429,  354,  428,  427,  426,  425,
      450,  424,  423,  422,  450,  421,  354,  354,  354,  354,
      355,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      355,  355,  355,  420,  419,  355,  402,  400,  398,  451,
      396,  394,  388,  355,  355,  355,  355,  387,  451,  451,
      451,  451,  383,  377,  368,  366,  364,  353,  355,  352,
      355,  451,  355,  451,  349,  348,  347,  346,  328,  324,
      323,  322,  321,  319,  313,  310,  299,  451,  355,  296,
      282,  451,  279,  355,  355,  355,  355,  405,  405,  405,
      405,  405,  405,  405,  405,  405,  405,  405,  405,  405,

      405,  405,  405,  405,  405,  405,  453,  278,  277,  274,
      405,  405,  405,  405,  273,  453,  453,  453,  453,  272,
      271,  270,  253,  249,  246,  405,  405,  405,  453,  405,
      453,  245,  236,  224,  222,  221,  211,  210,  208,  206,
      195,  193,  192,  189,  453,  187,  185,  184,  453,  183,
      405,  405,  405,  405,  405,  418,  418,  181,  418,  178,
      176,  175,  418,  418,  418,  418,  418,  418,  174,  173,
      418,  155,  152,  148,  512,  144,  137,  135,  418,  115,
      418,  418,  113,  512,  512,  512,  512,  111,  108,  107,
      105,  103,   98,  418,   86,  418,  512,   84,  512,   82,

       81,   79,   76,   75,   74,   67,   66,   60,   56,   52,
      418,   36,  512,   33,   32,   25,  512,    9,    2,  418,
      418,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,    1,    0,  433,    0,    0,    0,
      513,    0,    0,    0,  433,  433,  433,  433,    0,  513,
      513,  513,  513,    0,    0,    0,    0,    0,    0,  433,
        0,  433,  513,  433,  513,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  513,  433,
        0,    0,  513,    0,  433,  433,  433,  433,  434,  434,
      434,  434,  434,  434,  434,  434,  434,  434,  434,  434,

      434,    0,    0,  434,    0,    0,    0,  514,    0,    0,
        0,  434,  434,  434,  434,    0,  514,  514,  514,  514,
        0,    0,    0,    0,    0,    0,  434,    0,  434,  514,
      434,  514,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  434,    0,  514,    0,    0,    0,  514,
        0,  434,  434,  434,  434,  449,    0,    0,    0,  449,
      518,  449,    0,    0,  449,  449,  449,  449,    0,  518,
      518,  518,  518,    0,    0,    0,    0,  449,    0,  449,
        0,    0,  518,    0,  518,    0,    0,    0,    0,    0,
        0,    0,    0,  449,  519,    0,    0,  449,  518,  521,

        0,    0,  518,  519,  519,  519,  519,    0,  521,  521,
      521,  521,    0,    0,    0,    0,  519,    0,  519,    0,
        0,  521,    0,  521,    0,    0,    0,    0,    0,    0,
        0,    0,  519,  567,    0,    0,  519,  521,    0,    0,
        0,  521,  567,  567,  567,  567,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  567,    0,  567,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  567,    0,    0,    0,  567,  574,  574,  574,  574,
      574,  574,  574,  574,  574,  574,  574,  574,  574,  574,
      574,  574,  574,  574,  574,    0,    0,    0,    0,  574,

      574,  574,  574,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  574,  574,  574,    0,  574,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  574,
      574,  574,  574,  574,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,    0,    0,    0,    0,  578,  578,  578,
      578,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  578,  578,  578,    0,  578,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,  578,  578,  578,
      578,  578,  643,  643,  643,  643,  643,  643,  643,  643,
      643,  643,  643,  643,  643,  643,  643,  643,  643,  643,
      643,  643,  643,  643,  643,  643,  643,  643,  644,  644,
      644,  644,  644,  644,  644,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  644,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      646,  646,  646,  646,  646,  646,  646,  646,  646,  646,

      646,  646,  646,  646,  646,  646,  646,  646,  646,  646,
      646,  646,  646,  646,  646,  646,  647,  647,  647,  647,
      647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
      647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
      647,  647,  648,  648,  648,  648,  648,  648,  648,  648,
      648,  648,  648,  648,  648,  648,  648,  648,  648,  648,
      648,  648,  648,  648,  648,  648,  648,  648,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  650,    0,    0,    0,    0,    0,

        0,  650,    0,  650,  650,    0,  650,    0,  650,  650,
      650,  650,  650,    0,  650,  650,  650,  650,  650,  650,
      651,  651,  651,  651,  651,  651,  651,  651,  651,  651,
      651,  651,  651,  651,  651,  651,  651,  651,  651,  651,
      651,  651,  651,  651,  651,  651,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  653,  653,    0,  653,  653,  653,  653,  653,
      653,  653,  653,  653,  653,  653,  653,  653,  653,  653,
      653,  653,  653,  653,  653,  653,  653,  653,  654,  654,

        0,  654,  654,  654,  654,  654,  654,  654,  654,  654,
      654,  654,  654,  654,  654,  654,  654,  654,  654,  654,
      654,  654,  654,  654,  655,  655,    0,    0,    0,    0,
      655,  655,  655,    0,  655,  655,  655,    0,  655,    0,
        0,  655,  655,    0,  655,    0,    0,  655,    0,  655,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  657,  657,    0,  657,
      657,    0,  657,  657,  657,  657,  657,  657,  657,  657,
      657,  657,    0,  657,  657,    0,  657,  657,    0,  657,

      657,  657,  658,  658,    0,    0,    0,    0,  658,  658,
      658,    0,  658,  658,  658,    0,  658,    0,  658,  658,
      658,    0,  658,    0,    0,  658,    0,  658,  659,  659,
      659,    0,  659,    0,    0,  659,  659,    0,  659,    0,
        0,    0,    0,  659,  660,  660,    0,  660,  660,  660,
      660,  660,  660,  660,  660,  660,  660,    0,  660,  660,
        0,  660,  660,    0,  660,    0,    0,    0,    0,  660,
      661,  661,  661,  661,  661,  661,  661,  661,  661,    0,
      661,  661,  661,    0,  661,  661,    0,  661,  661,    0,
      661,  661,  661,  661,  661,  661,  662,  662,  662,  662,

      662,  662,  662,  662,  662,    0,  662,  662,  662,    0,
      662,  662,  662,  662,  662,    0,  662,  662,  662,  662,
      662,  662,  663,  663,  663,  663,  663,  663,  663,  663,
      663,    0,  663,  663,  663,    0,  663,  663,    0,  663,
      663,    0,  663,  663,  663,  663,  663,  663,  664,    0,
      664,  664,    0,    0,  664,    0,    0,    0,  664,  664,
        0,  664,    0,    0,  664,  664,    0,  664,  665,  665,
        0,  665,  665,  665,  665,  665,  665,    0,  665,  665,
      665,  665,  665,  665,  665,  665,  665,    0,  665,  665,
        0,    0,  665,  665,  666,  666,  666,  666,  666,  666,

      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      667,  667,  667,  667,  667,  667,  667,  667,  667,  667,
      667,  667,  667,  667,  667,  667,  667,  667,  667,  667,
      667,  667,  667,  667,  667,  667,  668,  668,  668,  668,
      668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
      668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
      668,  668,  669,  669,  669,  669,  669,  669,  669,  669,
      669,  669,  669,  669,  669,  669,  669,  669,  669,  669,
      669,  669,  669,  669,  669,  669,  669,  669,  670,  670,

      670,  670,  670,  670,  670,  670,  670,  670,  670,  670,
      670,  670,  670,  670,  670,  670,  670,  670,  670,  670,
      670,  670,  670,  670,  671,  671,  671,  671,  671,  671,
      671,  671,  671,  671,  671,  671,  671,  671,  671,  671,
      671,  671,  671,  671,  671,  671,  671,  671,  671,  671,
      672,    0,    0,  672,    0,    0,  672,  672,    0,  672,
        0,    0,    0,    0,  672,  673,  673,    0,  673,    0,
        0,    0,  673,  674,    0,    0,  674,  674,    0,  674,
        0,  674,  675,  675,    0,  675,  675,  675,  675,  675,
      675,  675,  675,  675,  675,  675,  675,  675,  675,  675,

      675,  675,  675,  675,  675,  675,  675,  675,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  676,  676,  676,
      676,  676,  676,  676,  677,  677,  677,  677,  677,  677,
      677,  677,  677,  677,  677,  677,  677,  677,  677,  677,
      677,  677,  677,  677,  677,  677,  677,  677,  677,  677,
      678,    0,    0,    0,    0,    0,  678,    0,    0,  678,
      678,  679,  679,  679,  679,  679,  679,  679,  679,  679,
      679,  679,  679,  679,  679,  679,  679,  679,  679,  679,
      679,  679,  679,  679,  679,  679,  679,  680,  680,  680,

      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
      680,  680,  680,  681,    0,    0,  681,    0,    0,  681,
      681,    0,  681,    0,    0,    0,    0,  681,  682,    0,
      682,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  682,    0,    0,  682,  682,    0,  682,  683,  683,
        0,  683,  683,  683,  683,  683,  683,  683,  683,  683,
      683,  683,  683,  683,  683,  683,  683,  683,  683,  683,
      683,  683,  683,  683,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,

      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
      685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
      685,  685,  685,  685,  685,  685,  686,  686,    0,  686,
      686,  686,  686,  686,  686,  686,  686,  686,  686,  686,
      686,  686,  686,  686,  686,  686,  686,  686,  686,  686,
      686,  686,  687,  687,  687,  687,  687,  687,  687,  687,
      687,  687,  687,  687,  687,  687,  687,  687,  687,  687,
      687,  687,  687,  687,  687,  687,  687,  687,  688,  688,
      688,  688,  688,  688,  688,  688,  688,  688,  688,  688,

      688,  688,  688,  688,  688,  688,  688,  688,  688,  688,
      688,  688,  688,  688,  689,  689,  689,  689,  689,  689,
      689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
      689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
      690,  690,  690,  690,  690,  690,  690,  690,  690,  690,
      690,  690,  690,  690,  690,  690,  690,  690,  690,  690,
      690,  690,  690,  690,  690,  690,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  692,    0,    0,  692,    0,    0,  692,  692,

        0,  692,    0,    0,    0,    0,  692,  693,  693,    0,
      693,    0,    0,  693,  693,    0,  693,    0,    0,    0,
        0,  693,  694,  694,  694,    0,  694,    0,  694,  694,
      694,    0,  694,    0,    0,    0,    0,  694,  695,    0,
      695,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  695,    0,    0,  695,  695,    0,  695,  696,    0,
        0,  696,  696,    0,  696,    0,  696,  697,  697,    0,
        0,    0,    0,  697,  697,  697,    0,  697,  697,  697,
        0,  697,    0,  697,  697,  697,    0,  697,    0,    0,
      697,    0,  697,  698,  698,  698,  698,  698,  698,  698,

      698,  698,    0,  698,  698,  698,    0,  698,  698,  698,
      698,  698,    0,  698,  698,  698,  698,  698,  698,  699,
      699,  699,  699,  699,  699,  699,  699,  699,    0,  699,
      699,  699,    0,  699,  699,  699,  699,  699,    0,  699,
      699,  699,  699,  699,  699,  700,  700,  700,  700,  700,
      700,  700,  700,  700,    0,  700,  700,  700,    0,  700,
      700,    0,  700,  700,    0,  700,  700,  700,  700,  700,
      700,  701,  701,    0,  701,  701,  701,  701,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  701,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  702,  702,    0,

      702,  702,  702,  702,  702,  702,  702,  702,  702,  702,
      702,  702,  702,  702,  702,  702,  702,  702,  702,  702,
      702,  702,  702,  703,  703,  703,  703,  703,  703,  703,
      703,  703,  703,  703,  703,  703,  703,  703,  703,  703,
      703,  703,  703,  703,  703,  703,  703,  703,  703,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,

      705,  708,    0,  708,  708,    0,    0,  708,    0,    0,
      708,  708,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  710,  710,
      710,  710,  710,  710,  710,  710,  710,  710,  710,  710,
      710,  710,  710,  710,  710,  710,  710,  710,  710,  710,
      710,  710,  710,  710,  711,  711,  711,  711,  711,  711,
      711,  711,  711,  711,  711,  711,  711,  711,  711,  711,
      711,  711,  711,  711,  711,  711,  711,  711,  711,  711,
      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,

      712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  712,  712,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  713,  713,  713,  713,  713,  713,
      713,  713,  714,  714,  714,  714,  714,  714,  714,  714,
      714,  714,  714,  714,  714,  714,  714,  714,  714,  714,
      714,  714,  714,  714,  714,  714,  714,  714,  715,  715,
      715,  715,  715,  715,  715,  715,  715,  715,  715,  715,
      715,  715,  715,  715,  715,  715,  715,  715,  715,  715,
      715,  715,  715,  715,  716,  716,  716,  716,  716,  716,

      716,  716,  716,  716,  716,  716,  716,  716,  716,  716,
      716,  716,  716,  716,  716,  716,  716,  716,  716,  716,
      717,  717,    0,  717,    0,    0,  717,  717,    0,  717,
        0,    0,    0,    0,  717,  718,    0,    0,  718,    0,
        0,  718,  718,    0,  718,    0,    0,    0,    0,  718,
      719,  719,  719,    0,  719,    0,  719,  719,  719,    0,
      719,    0,    0,    0,    0,  719,  720,  720,  720,  720,
      720,  720,  720,  720,  720,  720,  720,  720,  720,  720,
      720,  720,  720,  720,  720,  720,  720,  720,  720,  720,
      720,  720,  721,  721,  721,  721,  721,  721,  721,  721,

      721,  721,  721,  721,  721,  721,  721,  721,  721,  721,
      721,  721,  721,  721,  721,  721,  721,  721,  722,  722,
        0,  722,    0,    0,  722,  722,    0,  722,    0,    0,
        0,    0,  722,  723,  723,  723,  723,  723,  723,  723,
      723,  723,  723,  723,  723,  723,    0,  723,  723,  723,
      723,  723,  723,  723,  723,  723,  723,  723,  723,  724,
      724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
      724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
      724,  724,  724,  724,  724,  725,  725,  725,  725,  725,
      725,  725,  725,  725,  725,  725,  725,  725,    0,  725,

      725,  725,  725,  725,  725,  725,  725,  725,  725,  725,
      725,  726,  726,  726,  726,  726,  726,  726,  726,  726,
      726,  726,  726,  726,  726,  726,  726,  726,  726,  726,
      726,  726,  726,  726,  726,  726,  726,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,

      642,  642,  642,  642,  642,  642
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
/*****************************************************************************
 *
 * 
 *
 * Copyright (C) 1997-2015 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <stack>
#include <algorithm>

#include "bufstr.h"
#include "debug.h"
#include "message.h"
#include "config.h"
#include "doxygen.h"
#include "util.h"
#include "condparser.h"

#include <assert.h>

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

#define ADDCHAR(c)    yyextra->outBuf->addChar(c)
#define ADDARRAY(a,s) yyextra->outBuf->addArray(a,s)

#define USE_STATE2STRING 0
  
struct commentcnvYY_CondCtx
{
  commentcnvYY_CondCtx(int line,QCString id,bool b) 
    : lineNr(line),sectionId(id), skip(b) {}
  int lineNr;
  QCString sectionId;
  bool skip;
};
  
struct CommentCtx
{
  CommentCtx(int line) 
    : lineNr(line) {}
  int lineNr;
};
  
struct commentcnvYY_state
{
  BufStr * inBuf = 0;
  BufStr * outBuf = 0;
  yy_size_t inBufPos = 0;
  int      col = 0;
  int      blockHeadCol = 0;
  bool     mlBrief = FALSE;
  int      readLineCtx = 0;
  bool     skip = FALSE;
  QCString fileName;
  int      lineNr = 0;
  int      condCtx = 0;
  std::stack<commentcnvYY_CondCtx> condStack;
  std::stack<int> commentStack;
  QCString blockName;
  int      lastCommentContext = 0;
  bool     inSpecialComment = FALSE;
  bool     inRoseComment= FALSE;
  int      stringContext = 0;
  int      charContext = 0;
  int      javaBlock = 0;
  bool     specialComment = FALSE;

  QCString aliasString;
  int      blockCount = 0;
  bool     lastEscaped = FALSE;
  int      lastBlockContext= 0;
  bool     pythonDocString = FALSE;
  int      nestingCount= 0;

  bool     vhdl = FALSE; // for VHDL old style --! comment

  SrcLangExt lang = SrcLangExt_Unknown;
  bool       isFixedForm = FALSE; // For Fortran
};

#if USE_STATE2STRING
static const char *stateToString(int state);
#endif
static inline int computeIndent(const char *s);

static void replaceCommentMarker(yyscan_t yyscanner,const char *s,int len);
static inline void copyToOutput(yyscan_t yyscanner,const char *s,int len);
static void startCondSection(yyscan_t yyscanner,const QCString &sectId);
static void endCondSection(yyscan_t yyscanner);
static void handleCondSectionId(yyscan_t yyscanner,const char *expression);
static void replaceAliases(yyscan_t yyscanner,const QCString &s);
static yy_size_t yyread(yyscan_t yyscanner,char *buf,yy_size_t max_size);
static void replaceComment(yyscan_t yyscanner,int offset);
static void clearCommentStack(yyscan_t yyscanner);

#undef  YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(yyscanner,buf,max_size);

// otherwise the filename would be the name of the converted file (*.cpp instead of *.l)
static inline const char *getLexerFILE() {return __FILE__;}
#include "doxygen_lex.h"

  //- start: NUMBER -------------------------------------------------------------------------
  // Note same defines in code.l: keep in sync
  //- end: NUMBER ---------------------------------------------------------------------------
  // C start comment 
  // C end comment
  // Cpp comment 
  // Optional any character
  // Optional white space
  // readline non special
  // Optional slash

#define INITIAL 0
#define Scan 1
#define SkipString 2
#define SkipChar 3
#define SComment 4
#define CComment 5
#define CNComment 6
#define Verbatim 7
#define VerbatimCode 8
#define ReadLine 9
#define CondLine 10
#define ReadAliasArgs 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct commentcnvYY_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 643 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 642 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
{ //Note similar code in code.l
                                      if (yyextra->lang!=SrcLangExt_Cpp) REJECT;
                                      copyToOutput(yyscanner,yytext,(int)yyleng); 
                                    }
	YY_BREAK
case 2:
YY_RULE_SETUP
{ /* eat anything that is not " / , or \n */
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                    }
	YY_BREAK
case 3:
YY_RULE_SETUP
{ /* eat , so we have a nice separator in long initialization lines */ 
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                    }
	YY_BREAK
case 4:
YY_RULE_SETUP
{ /* start of python long comment */
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->pythonDocString = TRUE;
                                       yyextra->nestingCount=1;
                                       clearCommentStack(yyscanner); /*  to be on the save side */
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
                                   }
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0; // Fortran doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       /* check for fixed format; we might have some conditional as part of multiline if like C<5 .and. & */
                                       if (yyextra->isFixedForm && (yyextra->col == 0))
                                       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng); 
                                         yyextra->nestingCount=0; // Fortran doesn't have an end comment
                                         clearCommentStack(yyscanner); /*  to be on the save side */
				         BEGIN(CComment);
                                         yyextra->commentStack.push(yyextra->lineNr);
				       }
				       else
				       {
				         REJECT;
				       }
				     }
  				   }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
{
  			             if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
                                   }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
{
  			             if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       if (yyextra->col == 0)
                                       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng); 
				       }
				       else
				       {
				         REJECT;
				       }
				     }
                                   }
	YY_BREAK
case 9:
YY_RULE_SETUP
{ /* start of a string */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->stringContext = YY_START;
				     BEGIN(SkipString); 
                                   }
	YY_BREAK
case 10:
YY_RULE_SETUP
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->charContext = YY_START;
                                     if (yyextra->lang!=SrcLangExt_VHDL)
                                     {
				       BEGIN(SkipChar);
                                     }
  				   }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
{ /* new line */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 3);
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
{ /* start C++ style special comment block */
  				     if (yyextra->mlBrief) 
				     {
				       REJECT; // bail out if we do not need to convert
				     }
				     else
				     {
				       int i=3;
				       if (yytext[2]=='/')
				       {
					 while (i<(int)yyleng && yytext[i]=='/') i++;
				       }
				       yyextra->blockHeadCol=yyextra->col;
				       copyToOutput(yyscanner,"/**",3); 
				       replaceAliases(yyscanner,QCString(yytext+i));
				       yyextra->inSpecialComment=TRUE;
				       //BEGIN(SComment); 
				       yyextra->readLineCtx=SComment;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 14:
/* rule 14 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ /* Start of Rational Rose ANSI C++ comment block */
                                     if (yyextra->mlBrief) REJECT;
                                     int i=17; //=strlen("//##Documentation");
				     yyextra->blockHeadCol=yyextra->col;
				     copyToOutput(yyscanner,"/**",3);
				     replaceAliases(yyscanner,QCString(yytext+i));
				     yyextra->inRoseComment=TRUE;
				     BEGIN(SComment);
  				   }
	YY_BREAK
case 15:
/* rule 15 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 3);
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ // next line contains an end marker, see bug 752712
				     yyextra->inSpecialComment=yytext[2]=='/' || yytext[2]=='!';
  				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 16:
/* rule 16 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ /* one line C++ comment */ 
				     yyextra->inSpecialComment=yytext[2]=='/' || yytext[2]=='!';
  				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
				   }
	YY_BREAK
case 17:
YY_RULE_SETUP
{ /* avoid matching next rule for empty C comment, see bug 711723 */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 18:
YY_RULE_SETUP
{ /* start of a C comment */
                                     if (yyextra->lang==SrcLangExt_Python)
				     {
				       REJECT;
                                     }
  			             yyextra->specialComment=(int)yyleng==3;
                                     yyextra->nestingCount=1;
                                     clearCommentStack(yyscanner); /*  to be on the save side */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                     if (yyextra->specialComment)
				       BEGIN(CComment); 
                                     else
				       BEGIN(CNComment); 
                                     yyextra->commentStack.push(yyextra->lineNr);
                                   }
	YY_BREAK
case 19:
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0; // Python doesn't have an end comment for #
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
  				   }
	YY_BREAK
case 21:
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->vhdl = TRUE;
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0;  // VHDL doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 22:
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0;  // Fortran doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 23:
case 24:
YY_RULE_SETUP
{ // Mail address, to prevent seeing e.g x@code-factory.org as start of a code block
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 25:
/* rule 25 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     copyToOutput(yyscanner,"@iliteral{code}",15); 
				     yyextra->lastCommentContext = YY_START;
				     yyextra->javaBlock=1;
				     yyextra->blockName=&yytext[1];
                                     BEGIN(VerbatimCode);
  				   }
	YY_BREAK
case 26:
/* rule 26 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     copyToOutput(yyscanner,"@iliteral",9); 
				     yyextra->lastCommentContext = YY_START;
				     yyextra->javaBlock=1;
				     yyextra->blockName=&yytext[1];
                                     BEGIN(VerbatimCode);
  				   }
	YY_BREAK
case 27:
YY_RULE_SETUP
{ /* start of markdown code block */
                                     if (!Config_getBool(MARKDOWN_SUPPORT))
                                     {
                                       REJECT;
                                     }
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     yyextra->lastCommentContext = YY_START;
                                     yyextra->javaBlock=0;
                                     yyextra->blockName=QCString(yytext).stripWhiteSpace().left(3);
                                     BEGIN(VerbatimCode);
                                   }
	YY_BREAK
case 28:
/* rule 28 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ /* start of a verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->lastCommentContext = YY_START;
				     yyextra->javaBlock=0;
                                     if (qstrcmp(&yytext[1],"startuml")==0)
                                     {
                                       yyextra->blockName="uml";
                                     }
                                     else
                                     {
				       yyextra->blockName=&yytext[1];
                                     }
                                     BEGIN(VerbatimCode);
  				   }
	YY_BREAK
case 29:
YY_RULE_SETUP
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->blockName=&yytext[1];
				     if (yyextra->blockName.at(1)=='[')
				     {
				       yyextra->blockName.at(1)=']';
				     }
				     else if (yyextra->blockName.at(1)=='{')
				     {
				       yyextra->blockName.at(1)='}';
				     }
				     else if (yyextra->blockName.at(1)=='(')
				     {
				       yyextra->blockName.at(1)=')';
				     }
				     yyextra->lastCommentContext = YY_START;
				     BEGIN(Verbatim);
  			           }
	YY_BREAK
case 30:
/* rule 30 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ /* start of a verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->blockName=&yytext[1];
				     yyextra->lastCommentContext = YY_START;
                                     BEGIN(Verbatim);
                                   }
	YY_BREAK
case 31:
YY_RULE_SETUP
{ /* escaped double quote */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 32:
YY_RULE_SETUP
{ /* escaped backslash */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 33:
YY_RULE_SETUP
{ /* any other character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 34:
YY_RULE_SETUP
{ /* end of verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
				     if (&yytext[1]==yyextra->blockName) // end of formula
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
				     else if (&yytext[4]==yyextra->blockName)
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
                                   }
	YY_BREAK
case 35:
YY_RULE_SETUP
{
                                     if (yyextra->javaBlock==0)
				     {
				       REJECT;
				     }
				     else
				     {
				       yyextra->javaBlock++;
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
				     }
                                   }
	YY_BREAK
case 36:
YY_RULE_SETUP
{
                                     if (yyextra->javaBlock==0)
				     {
				       REJECT;
				     }
				     else
				     {
				       yyextra->javaBlock--;
				       if (yyextra->javaBlock==0)
				       {
                                         copyToOutput(yyscanner," @endiliteral ",14);
				         BEGIN(yyextra->lastCommentContext);
				       }
				       else
				       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng);
				       }
				     }
  				   }
	YY_BREAK
case 37:
YY_RULE_SETUP
{ /* end of markdown code block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     if (yytext[0]==yyextra->blockName[0])
                                     {
                                       BEGIN(yyextra->lastCommentContext);
                                     }
                                   }
	YY_BREAK
case 38:
YY_RULE_SETUP
{ /* end of verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
				     if (&yytext[4]==yyextra->blockName)
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
                                   }
	YY_BREAK
case 39:
YY_RULE_SETUP
{ /* skip leading comments */
  				     if (!yyextra->inSpecialComment)
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
                                     else
                                     {
                                       int l=0;
                                       while (yytext[l]==' ' || yytext[l]=='\t')
                                       {
                                         l++;
                                       }
                                       copyToOutput(yyscanner,yytext,l);
                                       if (yyleng-l==3) // ends with //! or ///
                                       {
                                         copyToOutput(yyscanner," * ",3);
                                       }
                                       else // ends with //
                                       {
                                         copyToOutput(yyscanner,"//",2);
                                       }
                                     }
  				   }
	YY_BREAK
case 40:
YY_RULE_SETUP
{ /* any character not a backslash or new line or } */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 41:
/* rule 41 can match eol */
YY_RULE_SETUP
{ /* new line in verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 42:
YY_RULE_SETUP
{
  				     if (yyextra->blockName=="dot" || yyextra->blockName=="msc" || yyextra->blockName=="uml" || yyextra->blockName.at(0)=='f')
				     {
				       // see bug 487871, strip /// from dot images and formulas.
                                       int l=0;
                                       while (yytext[l]==' ' || yytext[l]=='\t')
                                       {
                                         l++;
                                       }
                                       copyToOutput(yyscanner,yytext,l);
				       copyToOutput(yyscanner,"   ",3);
				     }
				     else // even slashes are verbatim (e.g. \verbatim, \code)
				     {
				       REJECT;
				     }
  				   }
	YY_BREAK
case 43:
YY_RULE_SETUP
{ /* any other character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 44:
YY_RULE_SETUP
{ /* escaped character in string */
                                     if (yyextra->lang==SrcLangExt_Fortran || yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       unput(yytext[1]);
                                       copyToOutput(yyscanner,yytext,1);
                                     }
                                     else
                                     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                     }
                                   }
	YY_BREAK
case 45:
YY_RULE_SETUP
{ /* end of string */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     BEGIN(yyextra->stringContext); 
                                   }
	YY_BREAK
case 46:
YY_RULE_SETUP
{ /* any other string character */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
{ /* new line inside string (illegal for some compilers) */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 48:
YY_RULE_SETUP
{ /* escaped character */
                                     if (yyextra->lang==SrcLangExt_Fortran || yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       unput(yytext[1]);
                                       copyToOutput(yyscanner,yytext,1);
                                     }
                                     else
                                     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                     }
                                   }
	YY_BREAK
case 49:
YY_RULE_SETUP
{ /* end of character literal */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                     BEGIN(yyextra->charContext);
                                   }
	YY_BREAK
case 50:
YY_RULE_SETUP
{ /* any other string character */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
{ /* new line character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 52:
YY_RULE_SETUP
{ /* anything that is not a '*' or command */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 53:
YY_RULE_SETUP
{ /* stars without slashes */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 54:
YY_RULE_SETUP
{ /* end of Python docstring */
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->nestingCount--;
                                       yyextra->pythonDocString = FALSE;
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
  				   }
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
{ /* new line in comment */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     /* in case of Fortran always end of comment */
  				     if (yyextra->lang==SrcLangExt_Fortran)
				     {
				       BEGIN(Scan);
				     }
                                   }
	YY_BREAK
case 56:
YY_RULE_SETUP
{ /* nested C comment */
                                     if (yyextra->lang==SrcLangExt_Python ||
                                         yyextra->lang==SrcLangExt_Markdown)
				     {
				       REJECT;
                                     }
                                     yyextra->nestingCount++;
                                     yyextra->commentStack.push(yyextra->lineNr);
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 57:
YY_RULE_SETUP
{ /* end of C comment */
                                     if (yyextra->lang==SrcLangExt_Python ||
                                         yyextra->lang==SrcLangExt_Markdown)
				     {
				       REJECT;
				     }
				     else
				     {
				       copyToOutput(yyscanner,yytext,(int)yyleng);
                                       yyextra->nestingCount--;
                                       if (yyextra->nestingCount<=0)
                                       {
				         BEGIN(Scan);
                                       }
                                       else
                                       {
                                         //yyextra->nestingCount--;
                                         yyextra->commentStack.pop();
                                       }
				     }
                                   }
	YY_BREAK
/* Python an VHDL share CComment,CNComment, so special attention for ending comments is required */
case 58:
/* rule 58 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
                                     {
                                       REJECT;
                                     }
                                     else
                                     {
                                       if (yyextra->vhdl) // inside --! comment
                                       {
                                         yyextra->vhdl = FALSE;
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                       else // C-type comment
                                       {
                                         REJECT;
                                       }
                                     }
                                   }
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     if (yyextra->lang!=SrcLangExt_Python || yyextra->pythonDocString)
				     {
				       REJECT;
				     }
				     else
				     {
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
                                   }
	YY_BREAK
case 60:
/* rule 60 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     if (yyextra->lang==SrcLangExt_Python)
                                     {
                                       if (yyextra->pythonDocString)
                                       {
                                         REJECT;
                                       }
                                       else
                                       {
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                     }
                                     else if (yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       if (yyextra->vhdl) // inside --! comment
                                       {
                                         yyextra->vhdl = FALSE;
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                       else // C-type comment
                                       {
                                         REJECT;
                                       }
                                     }
                                     else
                                     {
				       REJECT;
                                     }
                                   }
	YY_BREAK
/* removed for bug 674842 (bug was introduced in rev 768)
<CComment,CNComment>"'"			   {
  			             yyextra->charContext = YY_START;
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(SkipChar);
  				   }
<CComment,CNComment>"\""			   {
  			             yyextra->stringContext = YY_START;
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(SkipString);
  				   }
   */
case 61:
YY_RULE_SETUP
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
  				   }
	YY_BREAK
case 62:
/* rule 62 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
  				     replaceComment(yyscanner,0);
  				   }
	YY_BREAK
case 63:
/* rule 63 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
                                     replaceComment(yyscanner,1); 
                                   }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
{ 
  				     replaceComment(yyscanner,0);
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
  				   }
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
{   
                                     /* See Bug 752712: end the multiline comment when finding a @} or \} command */
                                     copyToOutput(yyscanner," */",3); 
				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->inSpecialComment=FALSE;
				     yyextra->inRoseComment=FALSE;
				     BEGIN(Scan); 
                                   }
	YY_BREAK
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
{ 
                                     replaceComment(yyscanner,1); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
  				   }
	YY_BREAK
case 67:
case 68:
/* rule 68 can match eol */
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
{    // or   //!something
  				     replaceComment(yyscanner,0);
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 70:
/* rule 70 can match eol */
case 71:
/* rule 71 can match eol */
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
{ 
                                     replaceComment(yyscanner,1); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
{
                                     if (!yyextra->inRoseComment)
				     {
				       REJECT;
				     }
				     else
				     {
  				       replaceComment(yyscanner,0);
				       yyextra->readLineCtx=YY_START;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
{
                                     if (!yyextra->inRoseComment)
				     {
				       REJECT;
				     }
				     else
				     {
                                       replaceComment(yyscanner,1); 
				       yyextra->readLineCtx=YY_START;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
{ /* end of special comment */
                                     copyToOutput(yyscanner," */",3); 
				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->inSpecialComment=FALSE;
				     yyextra->inRoseComment=FALSE;
				     BEGIN(Scan); 
                                   }
	YY_BREAK
case 76:
YY_RULE_SETUP
{
				     copyToOutput(yyscanner,"/&zwj;**",8);
				   }
	YY_BREAK
case 77:
YY_RULE_SETUP
{
				     copyToOutput(yyscanner,"*&zwj;/",7);
				   }
	YY_BREAK
case 78:
YY_RULE_SETUP
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				   }
	YY_BREAK
case 79:
YY_RULE_SETUP
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				   }
	YY_BREAK
case 80:
/* rule 80 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(yyextra->readLineCtx);
				   }
	YY_BREAK
case 81:
YY_RULE_SETUP
{ // escaped command
				     copyToOutput(yyscanner,yytext,(int)yyleng);
  				   }
	YY_BREAK
case 82:
/* rule 82 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 5);
yyg->yy_c_buf_p = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ // conditional section
  				     yyextra->condCtx = YY_START; 
  				     BEGIN(CondLine);
  				   }
	YY_BREAK
case 83:
/* rule 83 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 8);
yyg->yy_c_buf_p = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{ // end of conditional section
  				     bool oldSkip=yyextra->skip;
  				     endCondSection(yyscanner);
				     if (YY_START==CComment && oldSkip && !yyextra->skip) 
    			             {
				       //printf("** Adding start of comment!\n");
				       if (yyextra->lang!=SrcLangExt_Python &&
					   yyextra->lang!=SrcLangExt_VHDL &&
					   yyextra->lang!=SrcLangExt_Markdown &&
					   yyextra->lang!=SrcLangExt_Fortran)
				       {
 				         ADDCHAR('/');
     				         ADDCHAR('*');
					 if (yyextra->specialComment)
					 {
					   ADDCHAR('*');
					 }
				       }
    				     }
				    }
	YY_BREAK
case 84:
YY_RULE_SETUP
{
                                     handleCondSectionId(yyscanner,yytext);
  				   }
	YY_BREAK
case 85:
/* rule 85 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
{
  				     yyextra->condCtx=YY_START;
                                     handleCondSectionId(yyscanner," "); // fake section id causing the section to be hidden unconditionally
                                   }
	YY_BREAK
case 86:
/* rule 86 can match eol */
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
{ // forgot section id?
                                     handleCondSectionId(yyscanner," "); // fake section id causing the section to be hidden unconditionally
				     if (*yytext=='\n') { yyextra->lineNr++; copyToOutput(yyscanner,"\n",1);}
  				   }
	YY_BREAK
case 88:
YY_RULE_SETUP
{ // expand alias without arguments
				     replaceAliases(yyscanner,QCString(yytext));
  				   }
	YY_BREAK
case 89:
YY_RULE_SETUP
{ // expand alias with arguments
                                     yyextra->lastBlockContext=YY_START;
				     yyextra->blockCount=1;
				     yyextra->aliasString=yytext;
				     yyextra->lastEscaped=0;
				     BEGIN( ReadAliasArgs );
  				   }
	YY_BREAK
case 90:
YY_RULE_SETUP
{ // skip leading special comments (see bug 618079)
  				   }
	YY_BREAK
case 91:
YY_RULE_SETUP
{ // oops, end of comment in the middle of an alias?
                                     if (yyextra->lang==SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else // abort the alias, restart scanning
				     {
				       copyToOutput(yyscanner,yyextra->aliasString.data(),yyextra->aliasString.length());
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
  				   }
	YY_BREAK
case 92:
YY_RULE_SETUP
{
                                     yyextra->aliasString+=yytext;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 93:
YY_RULE_SETUP
{
                                     if (yyextra->lastEscaped)  yyextra->lastEscaped=FALSE;
                                     else                yyextra->lastEscaped=TRUE;
                                     yyextra->aliasString+=yytext;
                                   }
	YY_BREAK
case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
{
                                     yyextra->aliasString+=yytext;
                                     yyextra->lineNr++;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 95:
YY_RULE_SETUP
{
                                     yyextra->aliasString+=yytext;
                                     if (!yyextra->lastEscaped) yyextra->blockCount++;
				     yyextra->lastEscaped=FALSE;
                                   }
	YY_BREAK
case 96:
YY_RULE_SETUP
{
                                     yyextra->aliasString+=yytext;
				     if (!yyextra->lastEscaped) yyextra->blockCount--;
				     if (yyextra->blockCount==0)
				     {
				       replaceAliases(yyscanner,yyextra->aliasString);
				       BEGIN( yyextra->lastBlockContext );
				     }
				     yyextra->lastEscaped=FALSE;
  			           }
	YY_BREAK
case 97:
YY_RULE_SETUP
{
                                     yyextra->aliasString+=yytext;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 98:
YY_RULE_SETUP
{
  				     copyToOutput(yyscanner,yytext,(int)yyleng);
  				   }
	YY_BREAK
case 99:
YY_RULE_SETUP
{
  				     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
/*
<*>\n  { fprintf(stderr,"Lex scanner %s (%s) default rule newline for state %s.\n", __FILE__, qPrint(yyextra->fileName),stateToString(YY_START));}
  */
case 100:
YY_RULE_SETUP
ECHO;
	YY_BREAK
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(Scan):
			case YY_STATE_EOF(SkipString):
			case YY_STATE_EOF(SkipChar):
			case YY_STATE_EOF(SComment):
			case YY_STATE_EOF(CComment):
			case YY_STATE_EOF(CNComment):
			case YY_STATE_EOF(Verbatim):
			case YY_STATE_EOF(VerbatimCode):
			case YY_STATE_EOF(ReadLine):
			case YY_STATE_EOF(CondLine):
			case YY_STATE_EOF(ReadAliasArgs):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 643 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 643 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 642);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

static void replaceCommentMarker(yyscan_t yyscanner,const char *s,int len)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  const char *p=s;
  char c;
  // copy leading blanks
  while ((c=*p) && (c==' ' || c=='\t' || c=='\n')) 
  {
    ADDCHAR(c);
    yyextra->lineNr += c=='\n';
    p++;
  }
  // replace start of comment marker by blanks and the last character by a *
  int blanks=0;
  while ((c=*p) && (c=='/' || c=='!' || c=='#')) 
  {
    blanks++;
    p++;
    if (*p=='<') // comment-after-item marker 
    { 
      blanks++;
      p++; 
    }
    if (c=='!') // end after first !
    {
      break;
    }
  }
  if (blanks>0)
  {
    while (blanks>2)
    {
      ADDCHAR(' ');
      blanks--;
    }
    if (blanks>1) ADDCHAR('*');
    ADDCHAR(' ');
  }
  // copy comment line to output
  ADDARRAY(p,len-(int)(p-s));
}

static inline int computeIndent(const char *s)
{
  int col=0;
  static int tabSize=Config_getInt(TAB_SIZE);
  const char *p=s;
  char c;
  while ((c=*p++))
  {
    if (c==' ') col++;
    else if (c=='\t') col+=tabSize-(col%tabSize); 
    else break;
  }
  return col;
}

static inline void copyToOutput(yyscan_t yyscanner,const char *s,int len)
{
  int tabSize=Config_getInt(TAB_SIZE);
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  int i;
  if (yyextra->skip) // only add newlines.
  {
    for (i=0;i<len;i++)
    {
      switch(s[i])
      {
        case '\n':
	  ADDCHAR('\n');
	  yyextra->lineNr++;
          yyextra->col=0;
          break;
        case '\t':
          yyextra->col+=tabSize-(yyextra->col%tabSize);
          break;
        default:
          yyextra->col++;
          break;
      }
    }
  }
  else if (len>0)
  {
    ADDARRAY(s,len);
    for (i=0;i<len;i++) 
    {
      switch (s[i])
      {
	case '\n': yyextra->col=0; 
	           //fprintf(stderr,"---> copy %d\n",g_lineNr);
		   yyextra->lineNr++; break;
	case '\t': yyextra->col+=tabSize-(yyextra->col%tabSize); break;
	default:   yyextra->col++; break;
      }
    }
  }
}

static void clearCommentStack(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  while (!yyextra->commentStack.empty()) yyextra->commentStack.pop();
}

static void startCondSection(yyscan_t yyscanner,const QCString &sectId)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("startCondSection: skip=%d stack=%d\n",g_skip,g_condStack.count());
  CondParser prs;
  bool expResult = prs.parse(yyextra->fileName,yyextra->lineNr,sectId);
  yyextra->condStack.push(commentcnvYY_CondCtx(yyextra->lineNr,sectId,yyextra->skip));
  if (!expResult) // not enabled
  {
    yyextra->skip=TRUE;
  }
}

static void endCondSection(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->condStack.empty())
  {
    warn(yyextra->fileName,yyextra->lineNr,"Found \\endcond command without matching \\cond");
    yyextra->skip=FALSE;
  }
  else
  {
    const commentcnvYY_CondCtx &ctx = yyextra->condStack.top();
    yyextra->skip=ctx.skip;
    yyextra->condStack.pop();
  }
  //printf("endCondSection: skip=%d stack=%d\n",g_skip,g_condStack.count());
}

static void handleCondSectionId(yyscan_t yyscanner,const char *expression)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  bool oldSkip=yyextra->skip;
  startCondSection(yyscanner,QCString(expression));
  if ((yyextra->condCtx==CComment || yyextra->readLineCtx==SComment) && 
      !oldSkip && yyextra->skip) 
  {
    if (yyextra->lang!=SrcLangExt_Python &&
        yyextra->lang!=SrcLangExt_VHDL &&
        yyextra->lang!=SrcLangExt_Markdown &&
        yyextra->lang!=SrcLangExt_Fortran)
    {
      ADDCHAR('*');
      ADDCHAR('/');
    }
  }
  if (yyextra->readLineCtx==SComment)
  {
    BEGIN(SComment);
  }
  else
  {
    BEGIN(yyextra->condCtx);
  }
}

/** copies string \a s with length \a len to the output, while 
 *  replacing any alias commands found in the string.
 */
static void replaceAliases(yyscan_t yyscanner,const QCString &s)
{
  QCString result = resolveAliasCmd(s);
  //printf("replaceAliases(%s)->'%s'\n",s,result.data());
  copyToOutput(yyscanner,result.data(),result.length());
}

static yy_size_t yyread(yyscan_t yyscanner,char *buf,yy_size_t max_size)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yy_size_t bytesInBuf = yyextra->inBuf->curPos()-yyextra->inBufPos;
  yy_size_t bytesToCopy = std::min(max_size,bytesInBuf);
  memcpy(buf,yyextra->inBuf->data()+yyextra->inBufPos,bytesToCopy);
  yyextra->inBufPos+=bytesToCopy;
  return bytesToCopy;
}

static void replaceComment(yyscan_t yyscanner,int offset)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->mlBrief || yyextra->skip)
  {
    copyToOutput(yyscanner,yytext,(int)yyleng);
  }
  else
  {
    //printf("replaceComment(%s)\n",yytext);
    int i=computeIndent(&yytext[offset]);
    if (i==yyextra->blockHeadCol)
    {
      replaceCommentMarker(yyscanner,yytext,(int)yyleng);
    }
    else
    {
      copyToOutput(yyscanner," */",3);
      for (i=(int)yyleng-1;i>=0;i--) unput(yytext[i]);
      yyextra->inSpecialComment=FALSE;
      BEGIN(Scan);
    }
  }
}

/*! This function does three things:
 *  -# It converts multi-line C++ style comment blocks (that are aligned)
 *     to C style comment blocks (if MULTILINE_CPP_IS_BRIEF is set to NO).
 *  -# It replaces aliases with their definition (see ALIASES)
 *  -# It handles conditional sections (cond...endcond blocks)
 */
void convertCppComments(BufStr *inBuf,BufStr *outBuf,const QCString &fileName)
{
  yyscan_t yyscanner;
  commentcnvYY_state extra;
  commentcnvYYlex_init_extra(&extra,&yyscanner);
#ifdef FLEX_DEBUG
  commentcnvYYset_debug(1,yyscanner);
#endif
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("convertCppComments(%s)\n",fileName);
  yyextra->inBuf    = inBuf;
  yyextra->outBuf   = outBuf;
  yyextra->inBufPos = 0;
  yyextra->col      = 0;
  yyextra->mlBrief = Config_getBool(MULTILINE_CPP_IS_BRIEF);
  yyextra->skip     = FALSE;
  yyextra->fileName = fileName;
  yyextra->lang = getLanguageFromFileName(fileName);
  yyextra->pythonDocString = FALSE;
  yyextra->lineNr   = 1;
  while (!yyextra->condStack.empty()) yyextra->condStack.pop();
  clearCommentStack(yyscanner);
  yyextra->vhdl = FALSE;

  printlex(yy_flex_debug, TRUE, __FILE__, qPrint(fileName));
  yyextra->isFixedForm = FALSE;
  if (yyextra->lang==SrcLangExt_Fortran)
  {
    FortranFormat fmt = convertFileNameFortranParserCode(fileName);
    yyextra->isFixedForm = recognizeFixedForm(QCString(inBuf->data()),fmt);
  }

  if (yyextra->lang==SrcLangExt_Markdown)
  {
    yyextra->nestingCount=0;
    BEGIN(CComment);
    yyextra->commentStack.push(yyextra->lineNr);
  }
  else
  {
    BEGIN(Scan);
  }
  yylex(yyscanner);
  while (!yyextra->condStack.empty())
  {
    const commentcnvYY_CondCtx &ctx = yyextra->condStack.top();
    QCString sectionInfo(" ");
    if (ctx.sectionId!=" ") sectionInfo.sprintf(" with label '%s' ",ctx.sectionId.stripWhiteSpace().data());
    warn(yyextra->fileName,ctx.lineNr,"Conditional section%sdoes not have "
	"a corresponding \\endcond command within this file.",sectionInfo.data());
    yyextra->condStack.pop();
  }
  if (yyextra->nestingCount>0 && yyextra->lang!=SrcLangExt_Markdown && yyextra->lang!=SrcLangExt_Fortran)
  {
    QCString tmp("(probable line reference: ");
    bool first = TRUE;
    while (!yyextra->commentStack.empty())
    {
      int lineNr = yyextra->commentStack.top();
      if (!first) tmp += ", ";
      tmp += QCString().setNum(lineNr);
      first = FALSE;
      yyextra->commentStack.pop();
    }
    tmp += ")";
    warn(yyextra->fileName,yyextra->lineNr,"Reached end of file while still inside a (nested) comment. "
        "Nesting level %d %s",yyextra->nestingCount,tmp.data());
  }
  yyextra->nestingCount = 0;
  if (Debug::isFlagSet(Debug::CommentCnv))
  {
    yyextra->outBuf->at(yyextra->outBuf->curPos())='\0';
    Debug::print(Debug::CommentCnv,0,"-----------\nCommentCnv: %s\n"
                 "output=[\n%s]\n-----------\n",qPrint(fileName),yyextra->outBuf->data()
                );
  }
  printlex(yy_flex_debug, FALSE, __FILE__, qPrint(fileName));
  commentcnvYYlex_destroy(yyscanner);
}

//----------------------------------------------------------------------------

#if USE_STATE2STRING
#include "commentcnv.l.h"
#endif

